// -*- arduino -*-
// Meissner configuration file
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef MEISSNER_CONFIG_H
#define MEISSNER_CONFIG_H	1

#include <stddef.h>
#include <stdlib.h>
#include <inttypes.h>

#if defined(ARDUINO_SAMD_CIRCUITPLAYGROUND_EXPRESS)
#include <Adafruit_CircuitPlayground.h>

#elif defined(ARDUINO) && ARDUINO >= 100
#include <Arduino.h>

#else
#include <WProgram.h>
#include <WConstants.h>
#endif


// Target machine conditionals:
#if defined(__arm__) && defined(CORE_TEENSY)
#include "Meissner_Config_Teensy.h"

#elif defined(_VARIANT_MATRIXPORTAL_M4_)
#include "Meissner_Config_Matrix_Portal.h"

#elif defined(ARDUINO_SAMD_CIRCUITPLAYGROUND_EXPRESS)
#include "Meissner_Config_CircuitExpress.h"

#elif defined(ARDUINO_SAMD_HALLOWING)
#include "Meissner_Config_Hallowing.h"

#elif defined(ARDUINO_HALLOWING_M4)
#include "Meissner_Config_Hallowing_M4.h"

#elif defined(ARDUINO_FEATHER_M4)
#include "Meissner_Config_Feather_M4.h"

#elif defined(ARDUINO_GEMMA_M0)
#include "Meissner_Config_Gemma_M0.h"

#elif defined(ARDUINO_TRINKET_M0)
#include "Meissner_Config_Trinket_M0.h"

#elif defined(ARDUINO_QTPY_M0)
#include "Meissner_Config_QT_PY_M0.h"

#elif defined(ARDUINO_ADAFRUIT_QTPY_ESP32_PICO)
#include "Meissner_Config_QT_PY_ESP32_PICO.h"

#elif defined(ARDUINO_ADAFRUIT_QTPY_ESP32C3)
#include "Meissner_Config_QT_PY_ESP32_C3.h"

#elif defined(ARDUINO_ADAFRUIT_FEATHER_RP2040)
#include "Meissner_Config_Feather_RP2040.h"

#elif defined(ARDUINO_ESP32C3_DEV)
#include "Meissner_Config_ESP32_C3.h"

#elif defined(ADAFRUIT_ITSYBITSY_M0)
#include "Meissner_Config_Itsy_Bitsy_M0.h"

#elif defined(ADAFRUIT_ITSYBITSY_M4_EXPRESS)
#include "Meissner_Config_Itsy_Bitsy_M4.h"

#elif defined(__AVR_ATmega328P__) || defined(__AVR_ATtiny85__) || defined(__AVR_ATmega32U4__)
#include "Meissner_Config_Avr.h"

#else
#warning "Fix processor recognition in Meissner_Config.h"
#define PROCESSOR_UNKNOWN	1			// something else
#endif

#if defined(SERIAL_PORT_USBVIRTUAL)
#if defined(ARDUINO_SAMD_ZERO) || defined(ARDUINO_FEATHER_M4) || defined(ARDUINO_FEATHER_RP2040) || defined(USBCON)
  // Required for Serial on Zero/M4 based boards
#undef  Serial
#define Serial SERIAL_PORT_USBVIRTUAL
#endif
#endif


// Default values for the pins if not defined above

#ifndef PIN_BUTTON
#define PIN_BUTTON				-1			// simple button usually connected
#endif

#ifndef PIN_BUTTON0
#define PIN_BUTTON0				PIN_BUTTON		// first button usually connected
#endif

#ifndef PIN_BUTTON1
#define PIN_BUTTON1				-1			// second button usually connected
#endif

#ifndef PIN_SLIDE_SWITCH
#define PIN_SLIDE_SWITCH			-1			// a pin typically connected to a slide switch
#endif

#ifndef PIN_LED
#define PIN_LED					-1			// LED (usually pin 13)
#endif

#ifndef PIN_SDA
#define PIN_SDA					-1			// i2c SDA pin
#endif

#ifndef PIN_SCL
#define PIN_SCL					-1			// i2c SCL pin
#endif

#ifndef PIN_RANDOM
#define PIN_RANDOM				-1			// analog pin used for setting the random number seed
#endif

#ifndef PIN_UNUSED
#define PIN_UNUSED				-1			// a digital pin, typically unused
#endif

#ifndef PIN_NEOPIXEL
#define PIN_NEOPIXEL				-1			// a pin typically used for internal Neopixels (ws2812b LEDs)
#endif

#ifndef PIN_INTERNAL_NEOPIXEL
#define PIN_INTERNAL_NEOPIXEL			-1			// a pin typically used for internal Neopixels (ws2812b LEDs)
#endif

#ifndef PIN_NEOPIXEL_SINGLE
#define PIN_NEOPIXEL_SINGLE			-1			// a secondary pin that has a single neopixel attached
#endif

#ifndef PIN_INTERNAL_DOTSTAR_DATA
#define PIN_INTERNAL_DOTSTAR_DATA		-1			// data pin for the internal dotstar
#endif

#ifndef PIN_INTERNAL_DOTSTAR_CLOCK
#define PIN_INTERNAL_DOTSTAR_CLOCK		-1			// clock pin for the internal dotstar
#endif

#ifndef PIN_DAC
#define PIN_DAC					-1			// pin to connect to a speaker (digital to analog converter)
#endif

#ifndef PIN_DAC0
#define PIN_DAC0				PIN_DAC			// first speaker DAC
#endif

#ifndef PIN_DAC1
#define PIN_DAC1				-1			// second speaker DAC
#endif

#ifndef PIN_MEISSNER_SWITCH
// If this is a featherboard, use the prop shield's default switch location.
#if defined(PIN_FEATHERWING_D4) && (PIN_FEATHERWING_D4 >= 0)
#define PIN_MEISSNER_SWITCH			PIN_FEATHERWING_D4	// use prop shield switch
#else
#define PIN_MEISSNER_SWITCH			-1			// no default switch pin
#endif
#endif

#ifndef PIN_MEISSNER_ANALOG
#if defined(PIN_FEATHERWING_A1) && (PIN_FEATHERWING_A1 >= 0)
#define PIN_MEISSNER_ANALOG			PIN_FEATHERWING_A1	// use feather A1 as default potentiometer pin
#else
#define PIN_MEISSNER_ANALOG			-1			// no default analog input pin
#endif
#endif

#ifndef PIN_TEMP_SENSOR
#define PIN_TEMP_SENSOR				-1			// an analog pin that returns the temperture in some fashion
#endif

#ifndef PIN_LIGHT_SENSOR
#define PIN_LIGHT_SENSOR			-1			// an analog pin that returns the amount of light
#endif

#ifndef PIN_VREF
#define PIN_VREF				-1			// voltage reference
#endif

#ifndef PROCESSOR_NAME
#define PROCESSOR_NAME				"Unknown microprocessor" // name
#endif

#ifndef USE_EEPROM
#define USE_EEPROM				0			// don't assume the microprocessor has eeprom
#endif

#ifndef USE_EEPROM_LIB
#define USE_EEPROM_LIB				0			// don't assume we can use the eeprom library
#endif

#ifndef USE_SERIAL_OUTPUT
#if defined (PROCESSOR_SAMD_ZERO) || defined (PROCESSOR_SAMD_M4) || defined (PROCESSOR_TEENSY_ARM) || defined (PROCESSOR_RP2040)
#define USE_SERIAL_OUTPUT			1			// We can do serial on Teensy, Adafruit SAMD arm systems
#else
#define USE_SERIAL_OUTPUT			0			// don't assume we can do output to Serial
#endif

#elif   NO_SERIAL
#undef  USE_SERIAL_OUTPUT
#define USE_SERIAL_OUTPUT			0			// make sure no serial on ATtiny85
#endif

#ifndef USE_SERIAL_PRINTF						// Only enable Serial.printf if we think it will work
#define USE_SERIAL_PRINTF			0
#endif


#ifndef DIGITAL_OUTPUT_OK
#define DIGITAL_OUTPUT_OK(PIN)			1			// assume all pins are digital output pins
#endif

#ifndef DIGITAL_INPUT_OK
#define DIGITAL_INPUT_OK(PIN)			1			// assume all pins are digital input pins
#endif

#ifndef ANALOG_INPUT_OK
#define ANALOG_INPUT_OK(PIN)			1			// assume all pins are analog input pins
#endif


// Defaults for old names.

#if !defined(PIN_EXTERNAL_NEOPIXEL) && defined(PIN_FEATHERWING_D6)
#define PIN_EXTERNAL_NEOPIXEL			PIN_FEATHERWING_D6	// for feathers, use D6 which the prop shield has a level shifter for
#endif

#if !defined(PIN_NEOPIXEL) && defined(PIN_EXTERNAL_NEOPIXEL)
#define PIN_NEOPIXEL				PIN_EXTERNAL_NEOPIXEL
#endif

// Define the default pins for featherwings
#ifdef  PIN_FEATHERWING_D0

// OLED 128x32 and 128x64 feather wings
#define PIN_FEATHERWING_DOTSTAR_CIN		PIN_FEATHERWING_D0	// Dotstar clock pin
#define PIN_FEATHERWING_DOTSTAR_DIN		PIN_FEATHERWING_D2	// Dotstar data pin
#define PIN_FEATHERWING_NEOPIXEL		PIN_FEATHERWING_D5	// Neopixel data pin
#define PIN_FEATHERWING_OLED_BUTTON_A		PIN_FEATHERWING_D4	// OLED button A
#define PIN_FEATHERWING_OLED_BUTTON_B		PIN_FEATHERWING_D5	// OLED button A
#define PIN_FEATHERWING_OLED_BUTTON_C		PIN_FEATHERWING_D6	// OLED button A
#define PIN_FEATHERWING_OLED_RESET		PIN_FEATHERWING_A1	// OLED reset button on meissner OLED screen

// Prop maker featherwing
#define PIN_FEATHERWING_PROP_BLUE		PIN_FEATHERWING_D0	// Blue LED pin
#define PIN_FEATHERWING_PROP_GREEN		PIN_FEATHERWING_D1	// Green LED pin
#define PIN_FEATHERWING_PROP_RED		PIN_FEATHERWING_D2	// Red LED pin
#define PIN_FEATHERWING_PROP_POWER		PIN_FEATHERWING_D3	// Enable power to NeoPixels, Audio amplifier, and RGB pixesl
#define PIN_FEATHERWING_PROP_SWITCH		PIN_FEATHERWING_D4	// Switch pin for button/switch sensing, no pullup resistor
#define PIN_FEATHERWING_PROP_IRQ		PIN_FEATHERWING_D5	// Interrupt pin for LIS3DH accelerometer
#define PIN_FEATHERWING_PROP_NEOPIXEL		PIN_FEATHERWING_D6	// Data pin to drive neopixels
#define PIN_FEATHERWING_PROP_DAC		PIN_FEATHERWING_A0	// DAC for audio output
							
// Neopixel featherwing
#define PIN_FEATHERWING_NEOPIXEL		PIN_FEATHERWING_D5	// Default pin for neopixel featherwing

// E-paper featherwing
#define PIN_FEATHERWING_EPAPER_DC		PIN_FEATHERWING_D3	// D/C pin
#define PIN_FEATHERWING_EPAPER_CS_DISPLAY	PIN_FEATHERWING_D4	// CS pin for the display
#define PIN_FEATHERWING_EPAPER_CS_SRAM		PIN_FEATHERWING_D5	// CS pin for the SRAM memory
#define PIN_FEATHERWING_EPAPER_CS_SD		PIN_FEATHERWING_D6	// CS pin for the micro SD card reader

#else

// OLED 128x32 and 128x64 feather wings
#define PIN_FEATHERWING_DOTSTAR_CIN		-1			// Dotstar clock pin
#define PIN_FEATHERWING_DOTSTAR_DIN		-1			// Dotstar data pin
#define PIN_FEATHERWING_NEOPIXEL		-1			// Neopixel data pin
#define PIN_FEATHERWING_OLED_BUTTON_A		-1			// OLED button A
#define PIN_FEATHERWING_OLED_BUTTON_B		-1			// OLED button A
#define PIN_FEATHERWING_OLED_BUTTON_C		-1			// OLED button A
#define PIN_FEATHERWING_OLED_RESET		-1			// OLED reset button on meissner OLED screen

// Prop maker featherwing
#define PIN_FEATHERWING_PROP_BLUE		-1			// Blue LED pin
#define PIN_FEATHERWING_PROP_GREEN		-1			// Green LED pin
#define PIN_FEATHERWING_PROP_RED		-1			// Red LED pin
#define PIN_FEATHERWING_PROP_POWER		-1			// Enable power to NeoPixels, Audio amplifier, and RGB pixesl
#define PIN_FEATHERWING_PROP_SWITCH		-1			// Switch pin for button/switch sensing, no pullup resistor
#define PIN_FEATHERWING_PROP_IRQ		-1			// Interrupt pin for LIS3DH accelerometer
#define PIN_FEATHERWING_PROP_NEOPIXEL		-1			// Data pin to drive neopixels
#define PIN_FEATHERWING_PROP_DAC		-1			// DAC for audio output
							
// Neopixel featherwing
#define PIN_FEATHERWING_NEOPIXEL		-1			// Default pin for neopixel featherwing

// E-paper featherwing
#define PIN_FEATHERWING_EPAPER_DC		-1			// D/C pin
#define PIN_FEATHERWING_EPAPER_CS_DISPLAY	-1			// CS pin for the display
#define PIN_FEATHERWING_EPAPER_CS_SRAM		-1			// CS pin for the SRAM memory
#define PIN_FEATHERWING_EPAPER_CS_SD		-1			// CS pin for the micro SD card reader
#endif


// I2C addresses
const uint8_t	I2C_TEENSY_SGTL5000		= 0x0A;			// Teensy audio shield SGTL5000 (Audio Codec)
const uint8_t	I2C_TEENSY_WM8731		= 0x1A;			// Teensy audio shield WM8731 (Audio Codec)
const uint8_t	I2C_TEENSY_FXOS8700		= 0x1E;			// Teensy prop shield FXOS8700 (6 axis sensor)
const uint8_t	I2C_TEENSY_FXAS21002		= 0x20;			// Teensy prop shield FXAS21002 (gryoscope)
const uint8_t	I2C_MCP23008_BASE		= 0x20;			// MCP 23008 base (8 pin i2c expander)
const uint8_t	I2C_MCP23017_BASE		= 0x20;			// MCP 23017 base (16 pin i2c expander)
const uint8_t	I2C_LCD_CHAR_16_2		= 0x27;			// 16x2 character lcd in digispark lcd shield kit
const uint8_t	I2C_DIGIOLE_128_64		= 0x27;			// Digiole 128x64 LCD
const uint8_t	I2C_CAP1188_BASE		= 0x28;			// Adafruit Cap1188 capacitivie touch breakout board
const uint8_t	I2C_OLED_128_64			= 0x3C;			// 128x64 OLED from tindie.com
const uint8_t	I2C_FEATHER_OLED		= 0x3C;			// 128x32 OLED from adafruit.com (feather wing)
const uint8_t	I2C_FEATHER_PWM_BASE		= 0x40;			// Feather wing PWM base (0x40 - 0x7e)
const uint8_t	I2C_PCF8591_BASE		= 0x48;			// PCF 8591 4 analog->digital, 1 digital->analog
const uint8_t	I2C_DS3231_EEPROM		= 0x50;			// Generic DS3231 EEPROM
const uint8_t	I2C_TPA2016_AMP			= 0x58;			// Adafruit TPA2016 amplifier
const uint8_t	I2C_TEENSY_MPL3115		= 0x60;			// Teensy prop shield MPL3115 (presure sensor)
const uint8_t	I2C_FEATHER_MOTOR_BASE		= 0x60;			// Feather wing DC motor + stepper (0x60 - 0x7e)
const uint8_t	I2C_FEATHER_MOTOR_MRM		= 0x61;			// Feather wing DC motor + stepper (1st jumper soldered to not conflict with MPL3115)
const uint8_t	I2C_CHRONODOT			= 0x68;			// Adafruit chronodot real time clock
const uint8_t	I2C_DS3231_RTC			= 0x68;			// Generic DS3231 real time clock
const uint8_t	I2C_LED_MATRIX_BASE		= 0x70;			// Adafruit 8x8 LED matrix backpack base
const uint8_t	I2C_7SEGMENT			= 0x71;			// Sparkfun 7 segment display

#ifndef I2C_LIS3DH
const uint8_t	I2C_LIS3DH			= 0x18;			// Default LIS3DH address (note, Matrix portal has it as 0x19)
#endif


// Eeprom stuff if the machine supports it
#if USE_EEPROM
#include "Meissner_Config_Eeprom.h"

#else
const int16_t EEPROM_MAX			= -1;
const int16_t EEPROM_FIRST_RESERVED		= -1;

#endif	/* USE_EEPROM */
#endif	/* MEISSNER_CONFIG_H */


// HISTORY
// $Log: Meissner_Config.h,v $
// Revision 1.123  2022/09/09 02:45:05  michaelmeissner
// Add Hallowing_M4 support.
//
// Revision 1.122  2022/08/08 04:56:08  michaelmeissner
// Define PIN_INTERNAL_DOTSTAR_{DATA,CLOCK} if not defined.
//
// Revision 1.121  2022/07/24 21:09:41  michaelmeissner
// Add defaults for PIN_MEISSNER_{SWITCH,ANALOG} for feather capable boards.
//
// Revision 1.120  2022/07/24 20:52:34  michaelmeissner
// Add PIN_MEISSNER_{SWITCH,ANALOG}.  Remove setting some old names.
//
// Revision 1.119  2022/07/24 16:49:05  michaelmeissner
// Fix typos in single dotstar; Use correct if defined() for Itsy Bitsy M4.
//
// Revision 1.118  2022/07/24 16:22:08  michaelmeissner
// Add ItsyBisty M0/M4 support.
//
// Revision 1.117  2022/06/07 02:28:47  michaelmeissner
// Define PIN_INTERNAL_NEOPIXEL if not defined; Update comment.
//
// Revision 1.116  2022/06/01 04:08:20  michaelmeissner
// Add support for QT PY ESP32 pico.
//
// Revision 1.115  2022/04/12 03:02:23  michaelmeissner
// Add support for ESP32-C3 dev.
//
// Revision 1.114  2022/03/18 04:26:39  michaelmeissner
// Fix QT PY ESP32-C3 recognition.
//
// Revision 1.113  2022/03/18 04:13:49  michaelmeissner
// Add support for the Adafruit QT PY ESP32-C3.
//
// Revision 1.112  2022/03/14 02:40:44  michaelmeissner
// Define PIN_SINGLE_DOTSTAR_{CLOCK,DATA} from PIN_INTERNAL_DOTSTAR_{CLOCK,DATA}
//
// Revision 1.111  2022/03/14 02:30:04  michaelmeissner
// Spell PIN_NEOPIXEL_SINGLE correctly
//
// Revision 1.110  2022/03/14 02:28:50  michaelmeissner
// Define PIN_NEOPIXEL, PIN_EXTERNAL_NEOPIXEL, PIN_SINGLE_NEOPIXEL if not defined.
//
// Revision 1.109  2022/03/13 15:38:06  michaelmeissner
// Also check for USBCON for using SERIAL_PORT_USBVIRTUAL.
//
// Revision 1.108  2022/03/13 14:49:12  michaelmeissner
// Add support for Adafruit QT PY M0.
//
// Revision 1.107  2022/02/28 00:34:37  michaelmeissner
// Define USE_SERIAL_PRINTF if not already defined.
//
// Revision 1.106  2022/01/18 17:24:33  michaelmeissner
// Fix typos in rp2040 support.
//
// Revision 1.105  2022/01/18 17:14:35  michaelmeissner
// Update copyright year.
//
// Revision 1.104  2022/01/18 17:00:11  michaelmeissner
// Add initial support for Adafruit Feather RP2040.
//
// Revision 1.103  2021/01/05 17:14:52  michaelmeissner
// Spacing.
//
// Revision 1.102  2021/01/05 17:08:07  michaelmeissner
// Add prop maker, neopixel, and e-paper default pins.
//
// Revision 1.101  2020/12/12 04:20:10  michaelmeissner
// Fix typo.
//
// Revision 1.100  2020/12/05 23:49:02  michaelmeissner
// Spacing; Add address for LIS3DH, unless it is overriden in the board.
//
// Revision 1.99  2020/11/27 08:02:25  michaelmeissner
// Add Adafruit Matrix Portal.
//
// Revision 1.98  2020/02/02 04:13:01  michaelmeissner
// Fix recognizing Trinket M0.
//
// Revision 1.97  2020/01/17 07:38:47  michaelmeissner
// Enable serial output on Adafruit SAMD systems.
//
// Revision 1.96  2020/01/14 14:04:38  michaelmeissner
// Add support for Trinket-M0, Gemma-M0; Update copyright
//
// Revision 1.95  2019/01/14 02:12:01  michaelmeissner
// Update copyright; Undef Serial before redefining it.
//
// Revision 1.94  2019/01/06 14:24:11  michaelmeissner
// PIN_NEOPIXEL2 -> PIN_NEOPIXEL_SINGLE
//
// Revision 1.93  2019/01/06 05:35:45  michaelmeissner
// Define feather defaults to -1 if not defined.
//
// Revision 1.92  2019/01/06 04:34:30  michaelmeissner
// Fix off by one error in feather pins
//
// Revision 1.91  2019/01/06 03:04:17  michaelmeissner
// Add default pins for OLED, Dotstar, and Neopixel feather wings.
//
// Revision 1.90  2019/01/06 02:40:27  michaelmeissner
// Define Serial -> SerialUSB on M4 feather.
//
// Revision 1.89  2019/01/05 04:25:18  michaelmeissner
// Add support for Feather M4 express
//
// Revision 1.88  2018/12/28 00:24:15  michaelmeissner
// If NO_SERIAL, unset USE_SERIAL_OUTPUT.
//
// Revision 1.87  2018/12/28 00:21:54  michaelmeissner
// On Adafruit SAMD zero boards, define Serial to be SERIAL_PORT_USBVIRTUAL.
//
// Revision 1.86  2018/12/27 06:23:40  michaelmeissner
// Move eeprom info to separate file.
//
// Revision 1.85  2018/12/27 06:14:14  michaelmeissner
// Move most of the definitions to separate machine dependent files.
//
// Revision 1.84  2018/12/27 04:33:16  michaelmeissner
// Update copyright
//
// Revision 1.83  2018/12/26 08:23:27  michaelmeissner
// Turn off pin_random in playground express.
//
// Revision 1.82  2018/12/26 08:19:56  michaelmeissner
// Include Adafruit_CircuitPlayground.h if Circuit Playground Express; Don't define PIN_{LED,IR_TX,IR_RX}.
//
// Revision 1.81  2018/12/26 08:00:47  michaelmeissner
// No EEPROM.h on Circuit Playground Express.
//
// Revision 1.80  2018/12/26 07:53:18  michaelmeissner
// Add playground express pins
//
// Revision 1.79  2018/12/07 06:04:55  michaelmeissner
// Add support for Hallowing; Add short name for Circuit Playground Express.
//
// Revision 1.78  2018/12/07 06:00:27  michaelmeissner
// PROCESSOR_CIRCUIT_EXPRESS => PROCESSOR_CIRCUIT_PLAYGROUND_EXPRESS
//
// Revision 1.77  2018/12/07 05:55:25  michaelmeissner
// Add initial SAMD_ZERO (Circuit Express) support.
//
// Revision 1.76  2017/11/13 04:40:03  michaelmeissner
// Change comment.
//
// Revision 1.75  2017/11/13 04:37:27  michaelmeissner
// Change saved EEPROM elapsed time.
//
// Revision 1.74  2017/10/06 05:51:29  michaelmeissner
// Update copyright year.
//
// Revision 1.73  2016/10/20 13:36:01  michaelmeissner
// Eliminate PIN_DAT<x>
//
// Revision 1.72  2016/10/20 13:32:23  michaelmeissner
// Set PIN_UNUSED to be 40 on Teensy 3.5/3.6.
//
// Revision 1.71  2016/10/20 13:26:01  michaelmeissner
// Define both DAC and DAT
//
// Revision 1.70  2016/10/08 04:39:25  michaelmeissner
// Fix ANALOG_INPUT_OK.
//
// Revision 1.69  2016/10/05 04:31:42  michaelmeissner
// Add temp. sensor for Teensy analog inputs.
//
// Revision 1.68  2016/10/05 04:26:43  michaelmeissner
// Update digital/analog pins for Teensy 3.5/3.6.
//
// Revision 1.67  2016/10/03 03:23:13  michaelmeissner
// Fix typos in last change.
//
// Revision 1.66  2016/10/03 03:11:35  michaelmeissner
// Move meissner eeprom space higher on Teensy's; Rearrange EEPROM space somewhat.
//
// Revision 1.65  2016/10/03 02:40:14  michaelmeissner
// Delete a lot of unused EEPROM reservations.
//
// Revision 1.64  2016/10/02 12:52:10  michaelmeissner
// Bump EEPROM version
//
// Revision 1.63  2016/08/30 14:28:24  michaelmeissner
// Add various I2C addresses.
//
// Revision 1.62  2016/08/30 14:10:17  michaelmeissner
// Teensy 3.5/3.6 have 4k EEPROM.
//
// Revision 1.61  2016/08/29 15:48:29  michaelmeissner
// Put #endif on last page of code, not the comment page.
//
// Revision 1.60  2016/08/29 03:45:07  michaelmeissner
// Use PIN_TEMP_SENSOR for Teensy, like squarewear
//
// Revision 1.59  2016/08/29 03:42:05  michaelmeissner
// Fixup previous change.
//
// Revision 1.58  2016/08/29 03:36:23  michaelmeissner
// Add pin definitions for temperture, vref.
//
// Revision 1.57  2016/08/29 03:15:18  michaelmeissner
// Delete PIN_BUZZER, no longer used.
//
// Revision 1.56  2016/08/29 03:13:38  michaelmeissner
// Change default button for Teensy to 3.
//
// Revision 1.55  2016/08/09 14:58:26  michaelmeissner
// There are 58 pins on Teensy 3.5/3.6.
//
// Revision 1.54  2016/08/09 13:16:11  michaelmeissner
// Add initial support for Teensy 3.5/3.6.
//
// Revision 1.53  2016/04/03 22:42:49  michaelmeissner
// Make (C) in copyright be upper case.
//
// Revision 1.52  2016/04/02 14:31:27  michaelmeissner
// Add DAT pin for LC/3.1.
//
// Revision 1.51  2016/03/21 13:58:17  michaelmeissner
// Update copyright year.
//
// Revision 1.50  2016/03/16 12:40:41  michaelmeissner
// Add audio shield i2c addresses
//
// Revision 1.49  2016/03/16 12:29:40  michaelmeissner
// Add I2C addresses for the PROP shield; Update EEPROM_MAX for Teensy LC; Add EEPROM_NXPMOTION_{START,END}
//
// Revision 1.48  2016/03/15 15:18:40  michaelmeissner
// Add prop shield definitions.
//
// Revision 1.47  2015/11/25 12:50:05  michaelmeissner
// Allow EEPROM on ATtiny85, just don't enable Meissner_Eepromt
//
// Revision 1.46  2015/11/25 12:44:54  michaelmeissner
// Don't use EEPROM on either ATtiny85 or Teensy-LC
//
// Revision 1.45  2015/05/08 13:30:13  michaelmeissner
// Add PIN_BUTTON for Gemma/Trinket
//
// Revision 1.44  2015/05/08 04:35:13  michaelmeissner
// Change buzzer pin for the LC
//
// Revision 1.43  2015/03/08 15:10:09  michaelmeissner
// Change buzzer->3 on Teensy
//
// Revision 1.42  2015/03/06 23:05:47  michaelmeissner
// Change PIN_UNUSED on Teensy
//
// Revision 1.41  2015/02/26 06:13:30  michaelmeissner
// Change the neopixel pin on the Teensy-LC
//
// Revision 1.40  2015/02/15 18:07:34  michaelmeissner
// Fix typo in last change; Update digital/analog pin ok for Teensy's
//
// Revision 1.39  2015/02/15 17:50:50  michaelmeissner
// Check for unknown Teensy.
//
// Revision 1.38  2015/02/15 17:48:38  michaelmeissner
// Add initial Teensy-LC support.
//
// Revision 1.37  2015/02/15 17:43:52  michaelmeissner
// Teensy 3.0 does not have A14.
//
// Revision 1.36  2015/01/10 03:18:57  michaelmeissner
// Relicense under the MIT copyright so that we can link in neopixel patterns written by others.
//
// Revision 1.35  2015/01/10 03:10:56  michaelmeissner
// Use Copyright (c).
//
// Revision 1.34  2015/01/10 03:10:33  michaelmeissner
// Delete extra gpl lines that should have been deleted.
//
// Revision 1.33  2015/01/01 19:14:53  michaelmeissner
// Update copyright year
//
// Revision 1.32  2014/12/13 14:23:30  michaelmeissner
// Set random pin for ATtiny85
//
// Revision 1.31  2014/11/18 18:38:29  michaelmeissner
// Update copyright
//
// Revision 1.30  2014/10/11 04:06:38  michaelmeissner
// Change PIN_BUZZER back to 10 on Teensy, Uno
//
// Revision 1.29  2014/10/11 04:01:35  michaelmeissner
// Revamp pin assignment.
//
// Revision 1.28  2014/10/10 22:21:16  michaelmeissner
// Add initial defaults for squarewear
//
// Revision 1.27  2014-08-04 16:19:49  michaelmeissner
// On ATmega32u4, do not allow the overlapping analog pins to do digital output
//
// Revision 1.26  2014-08-01 04:24:11  michaelmeissner
// Add PROCESSOR_{ATMEGA32P,ATMEGA32U4} to test instead of UNO/LEONARDO.
//
// Revision 1.25  2014-08-01 04:21:34  michaelmeissner
// Assume pin 13 is the LED on a-star/leonardo
//
// Revision 1.24  2014-07-31 11:01:45  michaelmeissner
// Leonardo has 1k of eeprom
//
// Revision 1.23  2014-07-31 10:58:38  michaelmeissner
// Add initial a-star(leonardo) support.
//
// Revision 1.22  2014-05-14 22:06:50  michaelmeissner
// Fix typo in PIN_UNUSED; Add macros to say whether a pin can be used for digital input, digital output, or analog input.
//
// Revision 1.21  2014-05-14 15:48:53  michaelmeissner
// Drop elapsed time num_years; Expand num_weeks to 16-bits.
//
// Revision 1.20  2014-03-26 20:59:08  michaelmeissner
// Change spelling of Adafruit 8x8 led package and Sparkfun 7 segment displays i2c addresses.
//
// Revision 1.19  2014-03-26 20:55:54  michaelmeissner
// Fix spelling of chronodot
//
// Revision 1.18  2014-03-26 20:32:59  michaelmeissner
// Add more i2c devices, sort by i2c address.
//
// Revision 1.17  2014-03-26 20:23:46  michaelmeissner
// Allow for Teensy 3.1 #2
//
// Revision 1.16  2014-03-26 20:22:35  michaelmeissner
// Allow for Teensy 3.1
//
// Revision 1.15  2013-12-10 13:56:45  michaelmeissner
// Add Teensy 3.1 support; Add room to store __DATE__ and __TIME__ in EEPROM.
//
// Revision 1.14  2013-12-10 05:17:39  michaelmeissner
// Use defined(__arm__) && defined(CORE_TEENY) instead of defined(__MK20DX128__)
//
// Revision 1.13  2013-12-06 14:08:56  michaelmeissner
// Switch ATtin85 neopixel pin to the LED pin (#1)
//
// Revision 1.12  2013-11-18 03:20:17  michaelmeissner
// Make Neopixel pin 4 always
//
// Revision 1.11  2013-11-08 13:58:57  michaelmeissner
// Flesh out elapsed time support
//
// Revision 1.10  2013-11-07 16:16:36  michaelmeissner
// Add version/length eeprom fields.
//
// Revision 1.9  2013-11-07 15:43:28  michaelmeissner
// fix comment
//
// Revision 1.8  2013-11-07 15:42:35  michaelmeissner
// Add eeprom processor/sub-processor/ident, rename eeprom analog -> uint16 fields
//
// Revision 1.7  2013-11-07 15:28:49  michaelmeissner
// Drop static in static const int declarations; Add assignments for EEPROM storage
//
// Revision 1.6  2013-10-17 13:13:26  michaelmeissner
// Add PIN_UNUSED for the OLED display
//
// Revision 1.5  2013-10-11 13:54:50  michaelmeissner
// Use pin0 for ATtiny85 neopixels
//
// Revision 1.4  2013-10-11 13:32:14  michaelmeissner
// Include Arduino headers
//
// Revision 1.3  2013-10-11 13:25:25  michaelmeissner
// Add NO_{SERIAL,SERVO_H,WIRE_H}
//
// Revision 1.2  2013-10-11 13:21:54  michaelmeissner
// Add PIN_RANDOM
//
// Revision 1.1  2013-10-11 13:07:16  michaelmeissner
// Initial version.
//
