// -*- arduino -*-
// Meissner configuration file for AVR micro-processors.
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef _MEISSNER_CONFIG_AVR_H_
#define _MEISSNER_CONFIG_AVR_H_	1

#if defined(__AVR_ATmega328P__)
#define PROCESSOR_ATMEGA328P	1

// Whether a pin can be used for digital output
#define DIGITAL_OUTPUT_OK(PIN)	((PIN) != A6 && (PIN) != A7)
#define DIGITAL_INPUT_OK(PIN)	DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)	((PIN) >= A0 && (PIN) <= A7)

/* Assume a 12Mhz 328p is actually a squarewear.  */
#if F_CPU == 12000000L
#define PROCESSOR_SQUAREWEAR	1
#define PROCESSOR_NAME		"Squarewear"

#define PIN_BUTTON		 4			// Built-in push button pin
#define PIN_BUZZER		 9			// Built-in buzzer pin
#define PIN_EXTERNAL_NEOPIXEL	10			// Pin neopixel lights are connected to
#define PIN_LED			13			// Built-in LED pin
#define PIN_SDA			A4			// I2c SDC pin
#define PIN_SCL			A5			// I2c SCL pin
#define PIN_LED_BLUE		PIN_LED			// Blue  LED      (squarewear 2.0, not squarewear mini)
#define PIN_LED_RED		 8			// Red   LED      (squarewear 2.0, not squarewear mini)
#define PIN_LED_GREEN		12			// Green LED      (squarewear 2.0, not squarewear mini)
#define PIN_MOSFET1		 3			// First  MOSFET
#define PIN_MOSFET2		 5			// Second MOSFET
#define PIN_MOSFET3		 6			// Third  MOSFET  (squarewear 2.0, not squarewear mini)
#define PIN_LIGHT_SENSOR	A0			// Light sensor
#define PIN_TEMP_SENSOR		A1			// Temperture sensor
#define PIN_RANDOM		PIN_TEMP_SENSOR		// Analog pin to read for random number seed
#define PIN_UNUSED		PIN_LED			// Unused digital pin for tindie OLED display

#else	/* not squarewear */
#define PROCESSOR_UNO_R3	1			// assume anything else is an Arduino Uno
#define PROCESSOR_NAME		"ATmega 328p"

#define PIN_BUTTON		 2			// Pin with a push button
#define PIN_BUZZER		10			// Pin a buzzer is connected to
#define PIN_EXTERNAL_NEOPIXEL	 4			// Pin neopixel lights are connected to
#define PIN_LED			13			// Pin the built-in LED is on
#define PIN_SDA			A4			// Pin for i2c SDC
#define PIN_SCL			A5			// Pin for i2c SCL
#define PIN_RANDOM		A3			// Analog pin to read for random number seed
#define PIN_UNUSED		PIN_LED			// Unused digital pin for tindie OLED display
#endif	/* not squarewear */

#elif defined(__AVR_ATtiny85__)
#define PROCESSOR_ATTINY85	1			// run on ATtiny85 devices (trinket, gemma, digispark)
#define PROCESSOR_TRINKET	1
#define PROCESSOR_GEMMA		1
#define PROCESSOR_DIGISPARK	1
#define NO_SERIAL		1
#define NO_SERVO_H		1
#define NO_WIRE_H		1
#define PROCESSOR_NAME		"ATtiny 85"

#define PIN_BUTTON		0			// Pin with a push button (overlaps with I2C)
#define PIN_EXTERNAL_NEOPIXEL	1			// Pin neopixel lights are connected to
#define PIN_LED			1			// Built-in LED pin (Gemma/Trinket/Digispark), same as neopixel
#define PIN_SDA			0			// Pin for i2c SDC
#define PIN_SCL			2			// Pin for i2c SCL
#define PIN_RANDOM		2			// Analog pin to read for random number seed
#define PIN_UNUSED		PIN_RANDOM		// Unused digital pin for tindie OLED display

// Whether a pin can be used for digital output
#define DIGITAL_OUTPUT_OK(PIN)	1
#define DIGITAL_INPUT_OK(PIN)	1
#define ANALOG_INPUT_OK(PIN)	((PIN) >= 2 && (PIN) <= 5)

#elif defined(__AVR_ATmega32U4__)
#define PROCESSOR_ATMEGA32U4	1
#define PROCESSOR_LEONARDO	1
#define PROCESSOR_ASTAR		1
#define PROCESSOR_NAME		"ATmega 32U4"

#define PIN_BUTTON		 4			// Pin with a push button
#define PIN_BUZZER		 5			// Pin a buzzer is connected to
#define PIN_EXTERNAL_NEOPIXEL	 6			// Pin neopixel lights are connected to
#define PIN_LED			13			// Built-in LED pin
#define PIN_SDA			 2			// I2c SDC pin
#define PIN_SCL			 3			// I2c SDC pin
#define PIN_RANDOM		A5			// Analog pin to read for random number seed
#define PIN_UNUSED		PIN_RANDOM		// Unused digital pin for tindie OLED display

// Whether a pin can be used for digital output
/* On ATmega32u4, since the analog pins above 6 overlap with the digital pins,
   don't register the A<n> as a digital pin.  */
#define DIGITAL_OUTPUT_OK(PIN)	((PIN) < A6)
#define DIGITAL_INPUT_OK(PIN)	DIGITAL_OUTPUT_OK(PIN)
#define ANALOG_INPUT_OK(PIN)	((PIN) >= A0 && (PIN) <= A11)

#else
#error "Unknown AVR processor, fix Meissner_Config_Avr.h"
#endif

#endif	/* _MEISSNER_CONFIG_AVR_H_  */


// HISTORY
// $Log: Meissner_Config_Avr.h,v $
// Revision 1.6  2022/06/07 01:06:44  michaelmeissner
// PIN_NEOPIXEL -> PIN_EXTERNAL_NEOPIXEL.
//
// Revision 1.5  2022/03/14 01:50:42  michaelmeissner
// PIN_NEOPIXEL -> PIN_EXTERNAL_NEOPIXEL
//
// Revision 1.4  2022/01/18 17:16:23  michaelmeissner
// Update copyright year.
//
// Revision 1.3  2020/01/28 04:54:52  michaelmeissner
// Update copyright year.
//
// Revision 1.2  2019/01/14 02:12:41  michaelmeissner
// Update copyright.
//
// Revision 1.1  2018/12/27 06:09:03  michaelmeissner
// Initial version.
//
