// -*- arduino -*-
// Meissner configuration file for Gemma M0
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef _MEISSNER_CONFIG_GEMMA_M0_H_
#define	_MEISSNER_CONFIG_GEMMA_M0_H_		1

// Identify the processor
#define PROCESSOR_SAMD_ZERO			1
#define PROCESSOR_GEMMA_M0			1
#define PROCESSOR_NAME				"Adafruit Gemma M0"

#define PIN_SDA					SDA		// Pin for I2C SDC (D0/A2)
#define PIN_SCL					SCL		// Pin for I2C SCL (D2/A1)

#define USE_SERIAL_OUTPUT			1		// We can do output to Serial
#define USE_EEPROM				0		// No eeprom
#define USE_EEPROM_LIB				0		// No eeprom

#define PIN_BUTTON				2		// Use D2/A1 for a button
#define PIN_DAC					1		// Use D1/A0 for sound output (DAC)

								// Using pin D0/A2 allows us to use the
								// Adafruit_NeoPixel_ZeroDMA on the Gemma M0
#define PIN_EXTERNAL_NEOPIXEL			0		// Use D0/A2 for neopixel

#define PIN_INTERNAL_DOTSTAR_DATA		3		// Pin 3 is the 1 pixel dotstar data line
#define PIN_INTERNAL_DOTSTAR_CLOCK		4		// Pin 4 is the 1 pixel dotstar clock line
#define PIN_INTERNAL_DOTSTAR_NUM		1		// Just one dotstar

#ifndef PIN_LED
#define PIN_LED					-1		// No built-in LED (other than the dotstar LED)
#endif
#endif	/* _MEISSNER_CONFIG_GEMMA_M0_H_ */


// HISTORY
// $Log: Meissner_Config_Gemma_M0.h,v $
// Revision 1.7  2022/03/14 02:21:55  michaelmeissner
// PIN_NEOPIXEL -> PIN_EXTERNAL_NEOPIXEL; PIN_SINGLE_DOTSTAR_* -> PIN_INTERNAL_DOTSTAR_*; Add PIN_INTERNAL_DOTSTAR_NUM.
//
// Revision 1.6  2022/01/18 17:15:38  michaelmeissner
// Update copyright year.
//
// Revision 1.5  2020/01/28 00:46:44  michaelmeissner
// Add SDA/SCL pins, disable EEPROM, enable serial output.
//
// Revision 1.4  2020/01/28 00:39:20  michaelmeissner
// Change Neopixel pin to be the one that can be used with the ZeroDMA library.
//
// Revision 1.3  2020/01/17 07:11:53  michaelmeissner
// Move neopixel pin to pin 1.
//
// Revision 1.2  2020/01/15 17:04:00  michaelmeissner
// Add some defaults.
//
// Revision 1.1  2020/01/14 14:09:20  michaelmeissner
// Initial version.
