// -*- arduino -*-
// Meissner configuration file for Adafruit Itsy Bitsy M0
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef _MEISSNER_CONFIG_ITSY_BITSY_M0_H_
#define	_MEISSNER_CONFIG_ITSY_BITSY_M0_H_	1

// Identify the processor
#define PROCESSOR_SAMD_ZERO			1
#define PROCESSOR_ITSY_BITSY_M0			1
#define PROCESSOR_NAME				"Adafruit Itsy Bitsy M0"

#define PIN_SDA					SDA		// Pin for I2C SDC
#define PIN_SCL					SCL		// Pin for I2C SCL

#define USE_SERIAL_OUTPUT			1		// We can do output to Serial
#define USE_EEPROM				0		// No eeprom
#define USE_EEPROM_LIB				0		// No eeprom

// On the Itsy Bits microprocessors, use the 5th pin which is level shifted to
// VHI (highest voltage of VBAT and VBUS).  This is also one of the three Zero
// DMA pins (5, 12, MOSI) on the Itsy Bitsy M0.

#define PIN_EXTERNAL_NEOPIXEL			5		// Use level shifted pin for the external neopixel support

#define PIN_DAC					A0		// DAT (digital to analog)

#define PIN_INTERNAL_DOTSTAR_DATA		41		// Data pin for internal dotstar
#define PIN_INTERNAL_DOTSTAR_CLOCK		40		// Clock pin for internal dotstar
#define PIN_INTERNAL_DOTSTAR_NUM		1		// Only 1 internal dotstar

#ifndef PIN_LED
#define PIN_LED					13		// Internal LED
#endif

// Defaults for Meissner prototype boards.
// For button pin D12 (pin 12), which is simple to add a button connecting to ground
// For switch use D11 (pin 11), which is next to the button.
// For analog use A2  (pin 16), which is not a DAT pin
#define PIN_BUTTON				12		// Pin button in meissner prototype board layout.
#define PIN_MEISSNER_SWICH			11		// Pin switch in meissner prototype board layout.
#define PIN_MEISSNER_ANALOG			A2		// Pin for simple potentionmeter on Meissner prototype board layout.

// On the Itsy Bitsy M0:
// Chipset;		Microchip ATSAMD21
// Memory:		256KB flash, 32KB ram, 2MB SPI flash
// Hardware FP:		None
// Analog input pins:	A0/14, A1/15, A2/16, A3/17, A4/18, A5/19, A6/0, A7/1, A8/4, A9/3, A11/9, A12/42/VREFA
// PWM pins:		3, 4, 5, 9, 10, 11, 12, 13, A1/15, A2/16
// DAC pin:		A0/14
// AREF pins:		A12/42/VREFA, A3/17/VREFB
// Level shifted pin:	5
// I2C pins:		SCL/26, SDA/27 (need 2.2K pull-up resistors)
// I2S pins:		12 (SD0), 9 (SD0), 7 (FS0), 1 (SCK0), 0 (FS0), 4 (SD1), 3 (MCK0), 30/SCK (SCK1), 29/MOSI (MCK1)
// Touch pins:		A0/14, A1/15, A2/A16, A3/17, A4/18, A5/19, A12/VREFA, 9, 1, 0, 4, 3

#endif	/* _MEISSNER_CONFIG_ITSY_BITSY_M0_H_ */


// HISTORY
// $Log: Meissner_Config_Itsy_Bitsy_M0.h,v $
// Revision 1.6  2022/07/24 20:54:29  michaelmeissner
// Fix typo.
//
// Revision 1.5  2022/07/24 20:50:05  michaelmeissner
// Add Meissner defaults for button, switch, potentiometer.
//
// Revision 1.4  2022/07/24 16:43:34  michaelmeissner
// Update AREF pin comment.
//
// Revision 1.3  2022/07/24 16:40:35  michaelmeissner
// Update chipset, memory, hardware fp comments.
//
// Revision 1.2  2022/07/24 16:18:10  michaelmeissner
// Document M0 pins, remove 2nd DAC.
//
// Revision 1.1  2022/07/24 15:32:26  michaelmeissner
// Initial version.
//
