// -*- arduino -*-
// Meissner configuration file for Adafruit Itsy Bitsy M4
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef _MEISSNER_CONFIG_ITSY_BITSY_M4_H_
#define	_MEISSNER_CONFIG_ITSY_BITSY_M4_H_	1

// Identify the processor
#define PROCESSOR_SAMD_ZERO			1
#define PROCESSOR_ITSY_BITSY_M4			1
#define PROCESSOR_NAME				"Adafruit Itsy Bitsy M4"

#define PIN_SDA					SDA		// Pin for I2C SDC
#define PIN_SCL					SCL		// Pin for I2C SCL

#define USE_SERIAL_OUTPUT			1		// We can do output to Serial
#define USE_EEPROM				0		// No eeprom
#define USE_EEPROM_LIB				0		// No eeprom

// On the Itsy Bits microprocessors, use the 5th pin which is level shifted to
// VHI (highest voltage of VBAT and VBUS).  This is also one of the four Zero
// DMA pins (2, 5, 12, MOSI) on the Itsy Bitsy M4.

#define PIN_EXTERNAL_NEOPIXEL			5		// Use level shifted pin for the external neopixel support

// PIN_DAC0 and PIN_DAC1 are defined in the SAMD-M4 files.
#define PIN_DAC					A0		// first DAT (digital to analog)

#define PIN_INTERNAL_DOTSTAR_DATA		8		// Data pin for internal dotstar
#define PIN_INTERNAL_DOTSTAR_CLOCK		6		// Clock pin for internal dotstar
#define PIN_INTERNAL_DOTSTAR_NUM		1		// Only 1 internal dotstar

#ifndef PIN_LED
#define PIN_LED					13		// Internal red LED
#endif

// Defaults for Meissner prototype boards.
// For button pin D12 (pin 12), which is simple to add a button connecting to ground
// For switch use D11 (pin 11), which is next to the button.
// For analog use A2  (pin 16), which is not a DAT pin
#define PIN_BUTTON				12		// Pin button in meissner prototype board layout.
#define PIN_MEISSNER_SWICH			11		// Pin switch in meissner prototype board layout.
#define PIN_MEISSNER_ANALOG			A2		// Pin for simple potentionmeter on Meissner prototype board layout.

// On the Itsy Bitsy M4:
// Chipset:		Microchip ATSAMD51G19A
// Memory:		512KB flash, 192KB RAM, 2MB SPI Flash
// Hardware FP:		Single precision
// Analog input pins:	A0/14, A1/15, A2/16, A3/17, A4/18, A5/19, A6/2
// PWM pins:		RX/0, TX/1, 2, 4, 7, 9, 10, 11, 12, 13, A4/18, A5/19
// DAC pins:		A0/14, A1/15
// AREF pins:		AREF (tied to 3.3v), A4/18/VREFB, A5/19/VREFC
// Level shifted pin:	5
// I2C pins:		SCL/22, SDA/21 (need 2.2K pull-up resistors)
// I2S pins:		None
// Touch pins:		None

#endif	/* _MEISSNER_CONFIG_ITSY_BITSY_M4_H_ */


// HISTORY
// $Log: Meissner_Config_Itsy_Bitsy_M4.h,v $
// Revision 1.11  2022/07/25 01:08:10  michaelmeissner
// Fix data pin.
//
// Revision 1.10  2022/07/24 20:55:04  michaelmeissner
// Spacing.
//
// Revision 1.9  2022/07/24 20:53:51  michaelmeissner
// Add Meissner defaults for button, switch, potentiometer.
//
// Revision 1.8  2022/07/24 19:21:02  michaelmeissner
// Fix dotstar data/clock.
//
// Revision 1.7  2022/07/24 16:36:38  michaelmeissner
// Update memory and chipset information.
//
// Revision 1.6  2022/07/24 16:33:35  michaelmeissner
// Note that hardware FP is single precision.
//
// Revision 1.5  2022/07/24 16:27:38  michaelmeissner
// Remove defining PIN_DAC0/PIN_DAC1.
//
// Revision 1.4  2022/07/24 16:18:36  michaelmeissner
// Update AREF pins; Document no touch pins.
//
// Revision 1.3  2022/07/24 15:51:54  michaelmeissner
// Add comment about no I2S.
//
// Revision 1.2  2022/07/24 15:50:10  michaelmeissner
// Add comment describing pin functionality.
//
// Revision 1.1  2022/07/24 15:35:29  michaelmeissner
// Initial version.
//
