// -*- arduino -*-
// Meissner configuration file for Adafruit QT PY ESP32-C3
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef _MEISSNER_CONFIG_QT_PY_ESP32_C3_H_
#define	_MEISSNER_CONFIG_QT_PY_ESP32_C3_H_	1

// Identify the processor
#define PROCESSOR_QT_PY_ESP32_C3		1
#define PROCESSOR_NAME				"Adafruit QT PY ESP32-C3"

#define PIN_SDA					SDA		// Pin for I2C SDC
#define PIN_SCL					SCL		// Pin for I2C SCL

#define USE_SERIAL_OUTPUT			1		// We can do output to Serial
#define USE_EEPROM				0		// No eeprom
#define USE_EEPROM_LIB				0		// No eeprom

// Note, we use the SPI pins for neopixel and the button.  This way it doesn't
// use one of the 3 analog pins (A2 is used by the Adafruit LiIon or LiPoly
// Charger BFF Add-On for QT PY boards to measure the battery voltage).  The
// SPI pins are hard to use on the QT PY boards, because a typical SPI device
// uses 6 pins (SCLK, MISO, MOSI, CS, D/C, and reset), and there are only 10 or
// 11 pins.  In addition, we use MOSI to be compatible with the QT PY M0, since
// the MOSI pin is the only normal pin that can be used by the ZeroDMA library.

// For the default analog potentiometer, use A3, which avoids A0 (which might be a DAT).
// For the default switch

#define PIN_EXTERNAL_NEOPIXEL			MOSI		// Use pin MOSI for the external neopixel support
#define PIN_BUTTON				MISO		// Use MISO for a button
#define PIN_MEISSNER_SWICH			SCLK		// Pin switch in meissner prototype board layout.
#define PIN_MEISSNER_ANALOG			A3		// Pin for simple potentionmeter on Meissner prototype board layout.

#define PIN_DAC					-1		// No DAC support

#define PIN_INTERNAL_NEOPIXEL			2		// pin the internal neopixel is on
#define PIN_INTERNAL_NEOPIXEL_NUM		1		// just one internal neopixel
								// There is no pin to turn off power to the neopixel

#ifndef PIN_LED
#define PIN_LED					-1		// No built-in LED (other than the neopixel LED)
#endif
#endif	/* _MEISSNER_CONFIG_QT_PY_ESP32_C3_H_ */


// HISTORY
// $Log: Meissner_Config_QT_PY_ESP32_C3.h,v $
// Revision 1.5  2022/07/24 21:02:35  michaelmeissner
// Add default meissner switch, analog pin.
//
// Revision 1.4  2022/06/07 02:26:02  michaelmeissner
// Don't undef PIN_NEOPIXEL.
//
// Revision 1.3  2022/04/12 03:04:20  michaelmeissner
// QT Py Esp32-C3 is not a SAMD_M0.
//
// Revision 1.2  2022/03/18 04:43:58  michaelmeissner
// Update comment about pin choices.
//
// Revision 1.1  2022/03/18 04:19:33  michaelmeissner
// Initial version.
//

