// -*- arduino -*-
// Meissner configuration file for the Teensy LC/3.x/4.x micro-processors.
//
// Copyright (C) 2013-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#if defined(__arm__) && defined(CORE_TEENSY) && !defined(_MEISSNER_CONFIG_TEENSY_H_)
#define _MEISSNER_CONFIG_TEENSY_H_	1

#if defined(__MK20DX128__)
#define PROCESSOR_TEENSY_3_0		1
#define PROCESSOR_TEENSY_3_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1
#define PROCESSOR_NAME			"PJRC Teensy 3.0"

#elif defined(__MK20DX256__)
#define PROCESSOR_TEENSY_3_1		1	// 3.1 and 3.2 are identical except for the voltage regulator
#define PROCESSOR_TEENSY_3_2		1
#define PROCESSOR_TEENSY_3_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1
#define PROCESSOR_NAME			"PJRC Teensy 3.1/3.2"

#elif defined(__MKL26Z64__)
#define PROCESSOR_TEENSY_LC		1
#define PROCESSOR_NAME			"PJRC Teensy LC"

#elif defined(__MK64FX512__)
#define PROCESSOR_TEENSY_3_5		1
#define PROCESSOR_TEENSY_3_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1
#define PROCESSOR_NAME			"PJRC Teensy 3.5"

#elif defined(__MK66FX1M0__)
#define PROCESSOR_TEENSY_3_6		1
#define PROCESSOR_TEENSY_3_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1
#define PROCESSOR_NAME			"PJRC Teensy 3.6"

#elif defined(__IMXRT1052__)
#define PROCESSOR_TEENSY_4_BETA1	1
#define PROCESSOR_TEENSY_4_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1
#define PROCESSOR_NAME			"PJRC Teensy 4.0 Beta1"

#elif defined(__IMXRT1062__)
#define PROCESSOR_TEENSY_4		1
#define PROCESSOR_TEENSY_4_X		1
#define PROCESSOR_TEENSY_3_OR_4_X	1
#define PROCESSOR_TEENSY_ARM		1

#if defined(ARDUINO_TEENSY40)
#define PROCESSOR_TEENSY_4_0		1
#define PROCESSOR_TEENSY_4_1		1
#define PROCESSOR_NAME			"PJRC Teensy 4.0"

#elif defined(ARDUINO_TEENSY41)
#define PROCESSOR_TEENSY_4_1		1
#define PROCESSOR_NAME			"PJRC Teensy 4.1"

#else
#define PROCESSOR_NAME			"Unknown PJRC Teensy 4.x"
#endif

#else
#warning "Unknown Teensy, fix Meissner_Config_Teensy.h"
#define PROCESSOR_NAME			"PJRC Unknown Teensy"
#endif

#define PIN_BUTTON			 3	// Pin with a push button (use 3 because prop shield uses 2).
#define PIN_SDA				A4	// I2c SDC pin
#define PIN_SCL				A5	// I2c SCL pin
#define PIN_RANDOM			A11	// Analog pin to read for random number seed

#ifndef PIN_LED
#define PIN_LED				13	// Built-in LED pin
#endif
						// Unused digital pin for tindie OLED display
#if defined(PROCESSOR_TEENSY_3_5) || defined(PROCESSOR_TEENSY_3_6)
#define PIN_UNUSED			40	// On 3.5/3.6, pin 40 is underneath Teensy in the middle & has no special uses.

#elif defined(PROCESSOR_TEENSY_4_X)
#define PIN_UNUSED			30	// This pin is used for CRX3 but doesn't have other fixed usess.

#else
#define PIN_UNUSED			24	// On 3.0/3.1/3.2 pin 24 is underneath Teensy, On LC pin 24 is A10 on top/inside.
#endif

#define PIN_MEISSNER_SWITCH		 4	// Pin to connect a switch to switch to on some Meissner prototype shields, also switch pin on prop featherwing
#define PIN_MEISSNER_ANALOG		A1	// Analog pin to use analog input on Meissner prototype shields

// Prop shield definitions
#define PIN_PROP_I2C_INTERRUPT		 2	// Pin i2c interrupts are on
#define PIN_PROP_SPEAKER_SD		 5	// Pin to enable speaker
#define PIN_PROP_FLASH_CS		 6	// Pin for reading/writing flash memory
#define PIN_PROP_LED_ENABLE		 7	// Pin to enable 11/13 as outputs
#define PIN_PROP_LED_DATA		11	// Pin #1 for 5v LEDs (data for APA102/dotstar leds) 
#define PIN_PROP_LED_CLK		13	// Pin #2 for 5v LEDs (clock for APA102/dotstar leds) 

#define PIN_PROP_SPI_MOSI		11	// SPI MOSI pin
#define PIN_PROP_SPI_MISO		12	// SPI MISO pin
#define PIN_PROP_SPI_CLK		13	// SPI CLK pin

#if defined(PROP_SHIELD)
#define PIN_EXTERNAL_NEOPIXEL		11	// On prop shield use pin 11 for neopixels

// Use A3 for the neopixel on the LC, so that you can connect the neopixel to VIN
// On the Teensy 4.x processors it is TX4 which can be used with WS2812Serial
#else
#define PIN_EXTERNAL_NEOPIXEL		A3	// Pin neopixel lights are connected to
#endif

// Define the DAC digital/analog converter pin(s).
#if !defined(PIN_DAC)
#if defined(PROCESSOR_TEENSY_LC)
#define PIN_DAC				A12	// DAT (digital to analog)

#elif defined(PROCESSOR_TEENSY_3_2)
#define PIN_DAC				A14	// DAT (digital to analog)

#elif defined(PROCESSOR_TEENSY_3_5) || defined(PROCESSOR_TEENSY_3_6)
#define PIN_DAC				A21	// first DAT  (digital to analog)
#define PIN_DAC0			A21	// first DAT  (digital to analog)
#define PIN_DAC1			A22	// second DAT (digital to analog)
#endif
#endif

// Featherwing definitions
// Pins on the left side (16-pin side, Analog, SPI, UART)
#ifdef PIN_DAC
#define PIN_FEATHERWING_A0		PIN_DAC		// Analog pin 0

#else
#define PIN_FEATHERWING_A0		-1		// Teensy 4.x does not have a DAC.
#endif

#define PIN_FEATHERWING_A1		A1		// Analog pin 1
#define PIN_FEATHERWING_A2		A3		// Analog pin 2
#define PIN_FEATHERWING_A3		A2		// Analog pin 3
#define PIN_FEATHERWING_A4		A0		// Analog pin 4
#define PIN_FEATHERWING_A5		A6		// Analog pin 5
#define PIN_FEATHERWING_MOSI		11		// SPI MISO (input)  pin
#define PIN_FEATHERWING_MISO		12		// SPI MOSI (output) pin		
#define PIN_FEATHERWING_SCK		13		// SPI SCK  (clock)  pin
#define PIN_FEATHERWING_UART_RX		 0		// Serial0 RX pin
#define PIN_FEATHERWING_UART_TX		 1		// Serial0 TX pin

// Pins on right side (12-pin side)
#define PIN_FEATHERWING_D0		 5		// Digital pin 0, audio enable on Teensy Prop Shield
#define PIN_FEATHERWING_D1		 6		// Digital pin 1, Flash CS on Teensy Prop Shield
#define PIN_FEATHERWING_D2		 9		// Digital pin 2
#define PIN_FEATHERWING_D3		10		// Digital pin 3
#define PIN_FEATHERWING_D4		 4		// Digital pin 4
#define PIN_FEATHERWING_D5		 3		// Digital pin 5
#define PIN_FEATHERWING_D6		 8		// Digital pin 6

// Define the internal temperture sensor
#if defined(PROCESSOR_TEENSY_3_5) || defined(PROCESSOR_TEENSY_3_6)
#define PIN_TEMP_SENSOR			44	// temperture sensor
#define PIN_VREF			45	// VREF

#elif defined(PROCESSOR_TEENSY_LC)
#define PIN_TEMP_SENSOR			38	// temperture sensor

#elif defined(PROCESSOR_TEENSY_3_0) || defined(PROCESSOR_TEENSY_3_2)
#define PIN_TEMP_SENSOR			38	// temperture sensor
#define PIN_VREF			39	// VREF
#endif

// Whether to enable the Eeprom library or not
// The Teensy-LC is rather limited in the way it implements EEPROM, so don't use it

#if defined(PROCESSOR_TEENSY_LC)
#define USE_EEPROM			0
#define USE_EEPROM_LIB			0

#else
#define USE_EEPROM			0		// 1
#define USE_EEPROM_LIB			0		// 1
#endif

#define USE_SERIAL_OUTPUT		1		// We can do output to Serial
#define USE_SERIAL_PRINTF		1		// We can do printf to Serial

// Whether a pin can be used for digital output
// note each Teensy has a different number of analog pins and digital pins

#if defined(PROCESSOR_TEENSY_3_0)
#define DIGITAL_OUTPUT_OK(PIN)		(((PIN) < 33) && ((PIN) < A10 || (PIN) > A13))
#define DIGITAL_INPUT_OK(PIN)		DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)		(((PIN) >= A0 && (PIN) <= A9)		\
					 || ((PIN) >= A10 && (PIN) <= A13)	\
					 || (PIN) == PIN_TEMP_SENSOR)

#elif defined(PROCESSOR_TEENSY_3_2)
#define DIGITAL_OUTPUT_OK(PIN)		(((PIN) < 33) && ((PIN) < A10 || (PIN) > A13))
#define DIGITAL_INPUT_OK(PIN)		DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)		(((PIN) >= A0 && (PIN) <= A9)		\
					 || ((PIN) >= A10 && (PIN) <= A14)	\
					 || (PIN) == PIN_TEMP_SENSOR)

#elif defined(PROCESSOR_TEENSY_LC)
#define DIGITAL_OUTPUT_OK(PIN)		((PIN) < 23)
#define DIGITAL_INPUT_OK(PIN)		DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)		(((PIN) >= A0 && (PIN) <= A9)		\
					 || ((PIN) >= A10 && (PIN) <= A12)	\
					 || ((PIN) == PIN_TEMP_SENSOR))

#elif defined(PROCESSOR_TEENSY_3_5) || defined(PROCESSOR_TEENSY_3_6)
// Note the analog pin definitions have gaps:
//	A12 = 31, A13 = 32, A14 = 33, A15 = 34, A16 = 35, A17 = 36, A18 = 37, A19 = 38, A20 = 39,
//	A23 = 49, A24 = 50,
//	A10 = 64, A11 = 65, A21 = 66, A22 = 67, A25 = 68, A26 = 69

#if defined(PROCESSOR_TEENSY_3_5)
#define ANALOG_INPUT_TEENSY_3_5(PIN)	((PIN) >= A25 && (PIN) <= 26)
#else
#define ANALOG_INPUT_TEENSY_3_5(PIN)	0
#endif

#define DIGITAL_OUTPUT_OK(PIN)		((PIN) <= 57)
#define DIGITAL_INPUT_OK(PIN)		DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)		(((PIN) >= A0 && (PIN) <= A9)		\
					 || ((PIN) >= A12 && (PIN) <= A20)	\
					 || ((PIN) >= A23 && (PIN) <= A24)	\
					 || ((PIN) >= A10 && (PIN) <= A22)	\
					 || ((PIN) == PIN_TEMP_SENSOR)		\
					 || ANALOG_INPUT_TEENSY_3_5 (PIN))

// Pins A0..A14 are continous on the Teensy 4.0, and there are no analog only pins
// The temperature sensor is not accessed through an analog input pin
#elif defined(PROCESSOR_TEENSY_4_X)

#if defined(PROCESSOR_TEENSY_4_0)
#define DIGITAL_OUTPUT_OK(PIN)		((PIN) < 40)

#elif defined(PROCESSOR_TEENSY_4_1)
#define DIGITAL_OUTPUT_OK(PIN)		((PIN) < 40)

#else
#error "Unknown Teensy 4.x variant"
#endif

#define DIGITAL_INPUT_OK(PIN)		DIGITAL_OUTPUT_OK (PIN)
#define ANALOG_INPUT_OK(PIN)		((PIN) >= A0 && (PIN) <= A13)

#endif	/* Define pin ok macros.  */
#endif	/* _MEISSNER_CONFIG_TEENSY_H_  */


// Define pin layouts for 2 SPI controllers, typically used for paired displays
// with uncanny Eyes.  Define the pins here, so we can move displays around.

// Pins to avoid:	Teensy 4.x			Teensy 3.x
// ==============	==========			==========
// Pin 0		SPI-1 CS			---
// Pin 1		SPI-1 MISO			---
// Pin 2		---				SPI CS (overlaps with pin 10)
// Pin 3		Mrm push button			Mrm push button
// Pin 4		Mrm switch			Mrm switch
// Pin 5		---				---
// Pin 6		Audio/prop flash mem		Audio/prop flash mem, SPI CS (overlaps with pin 9)
// Pin 7		I2S-1 Out1			Alt. SPI-0 MOSI
// Pin 8		I2S-1 In1			Alt. SPI-0 MISO
// Pin 9		---				I2S BCLK, SPI CS (overlaps with pin 6)
// Pin 10		Audio micro SD card, SPI-0 CS	Audio micro SD card, SPI CS (overlaps with pin 2)
// Pin 11		SPI-0 MOSI			SPI MOSI, I2S MCLK
// Pin 12		SPI-0 MISO			SPI MISO
//
// Pin 13 (led)		SCLK-0				SPI SCLK, I2S RX
// Pin 14/A0		---				Alt. SPI SCLK
// Pin 15/A1		Audio volume			Audio volume, SPI CS
// Pin 16/A2		---				---
// Pin 17/A3		---				---
// Pin 18/A4		I2C SDA				I2C SDA
// Pin 19/A5		I2C SCL				I2C SCL
// Pin 20/A6		I2S LRCLK1			SPI CS (overlaps with pin 23/A9)
// Pin 21/A7		I2S BCLK1/feather pwr		feather pwr, SPI CS (overlaps with pin 22/A8)
// Pin 22/A8		---				I2S TX, SPI CS (overlaps with pin 21/A7)
// Pin 23/A9		I2S-1 MCLK			I2S LRCLK, SPI CS (overlaps with pin 20/A6)

// Common SPI-0 layout between Teensy 3.x systems and Teensy 4.x systems to
// reduce the number of breadboard and prototype boards setup.
//
// The layout for Teensy 3.x is set up for Uncanny Eyes running two displays
// off of the SPI bus.  The two CS pins and the D/C pin should be the 'special'
// hardware pins to speed up the display.  This assumes we aren't using the
// Audio adapter or I2S when we are using the 2nd display.  These special
// pins are:
//
//	Pin  2    or pin 10	(can't use both at the same time)
//	Pin  6    or pin  9	(can't use both at the same time)
//	Pin 15/A1
//	Pin 20/A6 or pin 23/A9	(can't use both at the same time)
//	Pin 21/A7 or pin 22/A8	(can't use both at the same time)
//
// We avoid pins 6, 10, 15/A1, 20/A6, 21/A7, and 23/A9 that might be used on
// Teensy 4.x systems with the Teensy 4.x audio adapter.
//
// To simplify making prototype boards and setting up breadboards, the SPI-0
// pins for Teensy 4.x systems should be the same as for Teensy 3.x systems.
//
// The typical layout for SPI pins is:
// Pin 1:	Ground
// Pin 2:	VIN (3.3v or maybe 5v)
// Pin 3:	SCLK
// Pin 4:	MOSI
// Pin 5:	MISO
// Pin 6:	CS-A		main CS pin
// Pin 7:	D/C
// Pin 8:	Reset
// Pin 9:	CS-B		second CS pin (for 2nd display or input device)
// Pin 10:	Blink		(for displays that need blink pin set high)
//
// In particular, using the DIP-40 and DIP-28 prototype boards from:
// https://www.tindie.com/products/drazzy/prototyping-board-with-breakaway-mounting-tabs/
//
// The DIP-28 boards has 10 pins across the front and back, while the DIP-40
// boards have 12 pins.

#define SPI0_MOSI	11	// Hardware SPI-0 output
#define SPI0_MISO	12	// Hardware SPI-0 input
#define SPI0_SCLK	13	// Hardware SPI-0 clock
#define SPI0_CS_A	A8	// SPI-0 main CS
#define SPI0_DC		 9	// SPI-0 D/C
#define SPI0_RESET	 5	// SPI-0 reset pin
#define SPI0_CS_B	10	// SPI-0 second display

#if PROCESSOR_TEENSY_4_X
// The pins for SPI0 should all be in the main pins (0..23) so any Teensy can
// use the main SPI device.  The 3 CS and D/C pins are chosen to be among the
// special 'CS' pins the Teensy 3.x microprocessors use.  If a second display
// on the first SPI bus isn't used (or SPI input), then there should be no
// conflict for pin 10 with the audio adapter.
//
// The pins for SPI1 should be the pins that both the Teensy 4.0 and 4.1
// support for the output support.  It is not anticipated that I will want to
// use a Teensy 4.0 to read from the SD drive from a second SPI display now
// that the Teensy 4.1 is available.  Otherise, it would mean that out Serial1
// (pins 0/1) was not available.

#define SPI0_CS_HW1	10	// Pin 10 is a special CS for SPI-0 for Teensy 4.x

#define SPI1_MOSI	26	// Hardware SPI-1 output
#define SPI1_SCLK	27	// Hardware SPI-1 clock
#define SPI1_CS_A	 0	// SPI-1 main CS
#define SPI1_DC		24	// SPI-1 D/C
#define SPI1_RESET	25	// SPI-1 reset
#define SPI1_CS_B	30	// SPI-1 secondary CS
#define SPI1_CS_HW1	 0	// Pin 0 is a special CS for SPI-1
#define SPI1_MISO	 1	// Hardware SPI-1 input

#if PROCESSOR_TEENSY_4_1
#define SPI1_ALT_MISO	39	// Hardware SPI-1 alternate input for Teensy 4.1
#define SPI1_CS_HW2	38	// Pin 38 is a special CS pin for SPI-1 Teensy 4.1
#define SPI0_CS_HW2	37	// Pin 37 is a special CS pin for SPI-0 Teensy 4.1
#define SPI0_CS_HW3	36	// Pin 36 is a special CS pin for SPI-0 Teensy 4.1

#else
#define SPI1_ALT_MISO	-1	// Hardware SPI-1 alternate MISO for Teensy 4.1
#endif	/* !PROCESSOR_TEENSY_4_1.  */
#endif	/* PROCESSOR_TEENSY_4_X.  */


// HISTORY
// $Log: Meissner_Config_Teensy.h,v $
// Revision 1.53  2022/09/21 03:42:32  michaelmeissner
// More SPI iterations #9.
//
// Revision 1.52  2022/09/20 23:01:35  michaelmeissner
// More SPI iterations #8.
//
// Revision 1.51  2022/09/20 22:57:53  michaelmeissner
// More SPI iterations #7.
//
// Revision 1.50  2022/09/20 20:43:59  michaelmeissner
// Make 2nd SPI 0 CS pin be pin 10, not 2.
//
// Revision 1.49  2022/09/20 20:42:01  michaelmeissner
// More SPI iterations #6.
//
// Revision 1.48  2022/09/20 15:01:57  michaelmeissner
// More SPI iterations #5.
//
// Revision 1.47  2022/09/20 02:45:59  michaelmeissner
// More SPI iterations #4.
//
// Revision 1.46  2022/09/20 02:14:08  michaelmeissner
// Change SP1 pins a bit for a Teensy 4.0 without all of the bottom pins exposed.
//
// Revision 1.45  2022/09/20 00:28:02  michaelmeissner
// More SPI iterations #2.
//
// Revision 1.44  2022/09/19 23:27:56  michaelmeissner
// More SPI iterations.
//
// Revision 1.43  2022/09/19 23:09:55  michaelmeissner
// Rework SPI pins so SPI0 is common between Teensy 3.x and 4.x #5.
//
// Revision 1.42  2022/09/19 21:19:50  michaelmeissner
// Rework SPI pins so SPI0 is common between Teensy 3.x and 4.x #4.
//
// Revision 1.41  2022/09/19 21:19:26  michaelmeissner
// Rework SPI pins so SPI0 is common between Teensy 3.x and 4.x #3.
//
// Revision 1.40  2022/09/19 21:09:27  michaelmeissner
// Add missing SCLK for Teensy 3.x.
//
// Revision 1.39  2022/09/19 21:08:10  michaelmeissner
// Rework SPI pins so SPI0 is common between Teensy 3.x and 4.x #2.
//
// Revision 1.38  2022/09/19 21:06:55  michaelmeissner
// Rework SPI pins so SPI0 is common between Teensy 3.x and 4.x.
//
// Revision 1.37  2022/09/19 20:26:52  michaelmeissner
// Add mrm switch (pin 4) in SPI pin discussion; Chagne SPI0 CS-A pin to 2.
//
// Revision 1.36  2022/09/19 19:55:28  michaelmeissner
// Don't define PROCESSOR_xxx macros if they are 0.
//
// Revision 1.35  2022/09/19 15:48:28  michaelmeissner
// Use A11 for random pin, not A10.
//
// Revision 1.34  2022/09/19 15:44:52  michaelmeissner
// Fix spelling of PIN_MEISSNER_SWITCH.
//
// Revision 1.33  2022/09/19 15:44:19  michaelmeissner
// Update for Teensy 4.x.
//
// Revision 1.32  2022/09/19 01:34:50  michaelmeissner
// Add Teensy 3.x spi pins.
//
// Revision 1.31  2022/09/06 22:24:42  michaelmeissner
// Update SPI pins #2.
//
// Revision 1.30  2022/09/06 16:43:10  michaelmeissner
// Update SPI pins.
//
// Revision 1.29  2022/09/04 03:53:55  michaelmeissner
// Swap the CS_B and CS_C pins.
//
// Revision 1.28  2022/09/03 23:50:49  michaelmeissner
// Add commentary about SPI pin layout.
//
// Revision 1.27  2022/09/02 22:05:21  michaelmeissner
// Add SPI0/SPI1 pins for Teensy 4.x.
//
// Revision 1.26  2022/08/08 04:43:21  michaelmeissner
// Make Teensy 3.2 header say 3.1/3.2.
//
// Revision 1.25  2022/07/24 20:42:07  michaelmeissner
// Add PIN_MEISSNER_{SWITCH,ANALOG}.
//
// Revision 1.24  2022/03/14 02:36:33  michaelmeissner
// PIN_NEOPIXEL -> PIN_EXTERNAL_NEOPIXEL.
//
// Revision 1.23  2022/02/28 00:35:21  michaelmeissner
// Define USE_SERIAL_PRINTF
//
// Revision 1.22  2022/01/18 17:16:05  michaelmeissner
// Update copyright year.
//
// Revision 1.21  2021/02/06 18:01:52  michaelmeissner
// Teensy 4.x does not have a DAC pin.
//
// Revision 1.20  2021/02/06 17:58:49  michaelmeissner
// Add Teensy 4.1 support.
//
// Revision 1.19  2021/02/06 17:45:29  michaelmeissner
// Fix typo.
//
// Revision 1.18  2020/12/29 00:43:59  michaelmeissner
// Disable Teensy EEPROM for now.
//
// Revision 1.17  2020/04/26 20:17:15  michaelmeissner
// Differentiate Teensy 4.0 from Teensy 4.1.
//
// Revision 1.16  2020/01/28 04:59:03  michaelmeissner
// Update copyright year.
//
// Revision 1.15  2019/09/03 15:41:09  michaelmeissner
// Add PROCESSOR_TEENSY_3_OR_4_X
//
// Revision 1.14  2019/09/03 05:22:01  michaelmeissner
// Fix typo.
//
// Revision 1.13  2019/08/17 15:07:29  michaelmeissner
// Update comment.
//
// Revision 1.12  2019/08/17 15:04:59  michaelmeissner
// Add Teensy 4.0 support.
//
// Revision 1.11  2019/08/17 14:46:25  michaelmeissner
// Add PROCESSOR_TEENSY_4_0
//
// Revision 1.10  2019/08/16 04:50:12  michaelmeissner
// Add PROCESSOR_TEENSY_ARM
//
// Revision 1.9  2019/08/16 04:49:13  michaelmeissner
// Undefine MEISSNER_TEENSY_3_X on Teensy 4.0
//
// Revision 1.8  2019/08/16 04:48:01  michaelmeissner
// Define PROCESSOR_TEENSY_3_X and PROCESSOR_TEENSY_4_X
//
// Revision 1.7  2019/07/09 03:45:31  michaelmeissner
// Add support for Teensy 4.0
//
// Revision 1.6  2019/02/09 04:11:24  michaelmeissner
// Add initial support for Teensy 4.x
//
// Revision 1.5  2019/01/17 16:37:01  michaelmeissner
// Add comments to featherwing pins.
//
// Revision 1.4  2019/01/14 02:14:47  michaelmeissner
// Update copyright.
//
// Revision 1.3  2019/01/06 05:15:11  michaelmeissner
// Add PIN_FEATHERWING_SCK
//
// Revision 1.2  2019/01/06 02:52:03  michaelmeissner
// Add featherwing pins.
//
// Revision 1.1  2018/12/27 06:11:52  michaelmeissner
// Initial version.
//
