// -*- arduino -*-
// Meissner delay library
// based on http://www.gammon.com.au/blink
//
// Copyright (C) 2014-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#include <stddef.h>
#include <stdlib.h>
#include <inttypes.h>

#if defined(ARDUINO) && ARDUINO >= 100
#include "Arduino.h"

#else
#include "WProgram.h"
#include "WConstants.h"
#endif

#include <Meissner_Delay.h>



// Return true if the delay is done

bool
Delay::delay_done (void)
{
  bool ret = false;

  if (immediate)
    {
      immediate = false;
      ret = true;
    }

  else if (init_time != 0UL)
    {
      if ((millis () - init_time) >= interval)
	ret = true;
    }

  if (ret)
    init_time = (repeat) ? millis () : 0UL;

  return ret;
}


// HISTORY
// $Log: Meissner_Delay.cpp,v $
// Revision 1.8  2022/02/13 01:04:05  michaelmeissner
// Update copyright year.
//
// Revision 1.7  2020/01/28 05:05:53  michaelmeissner
// Update copyright year.
//
// Revision 1.6  2019/01/14 02:16:25  michaelmeissner
// Update copyright.
//
// Revision 1.5  2016/03/21 13:59:10  michaelmeissner
// Update copyright year.
//
// Revision 1.4  2015/01/12 02:14:38  michaelmeissner
// Move delay_done code from .h file to .cpp file.
//
// Revision 1.3  2015/01/10 03:13:41  michaelmeissner
// Relicense under the MIT copyright so that we can link in neopixel patterns written by others.
//
// Revision 1.2  2015/01/01 19:15:50  michaelmeissner
// Update copyright year
//
// Revision 1.1  2014/12/31 13:55:33  michaelmeissner
// Initial version.
//
