// Arduino Morse Library
// Written by Erik Linder SM0RVV and Mark VandeWettering K6HX
//
// Released 2011 under GPLv3
//
// Version 0.2

// Code modified by Michael Meissner
// Code changes Copyright (C) 2012-2022, Michael Meissner
//
// Meissner_Morse is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 3, or (at your option) any later
// version.

#include <Meissner_Config.h>
#include <Meissner_Morse.h>

static const uint8_t morsetab[] = {		// Those with value 1 have no morsecode
  107,						// ASCII 33 !   
  82, 						// ASCII 34 "   
  1,  						// ASCII 35 #   
  137,						// ASCII 36 $   
  1,  						// ASCII 37 %   
  40, 						// ASCII 38 &   
  94, 						// ASCII 39 '  
  109,						// ASCII 40 (
  109,						// ASCII 41 )   
  1,  						// ASCII 42 *   
  42, 						// ASCII 43 +   
  115,						// ASCII 44 ,   
  97, 						// ASCII 45 -   
  85, 						// ASCII 46 .   
  50, 						// ASCII 47 /  
  63, 						// ASCII 48 0
  62, 						// ASCII 49 1
  60, 						// ASCII 50 2
  56, 						// ASCII 51 3
  48, 						// ASCII 52 4
  32, 						// ASCII 53 5
  33, 						// ASCII 54 6
  35, 						// ASCII 55 7
  39, 						// ASCII 56 8
  47, 						// ASCII 57 9
  120,						// ASCII 58 :
  53, 						// ASCII 59 ;
  1,  						// ASCII 60 <
  49, 						// ASCII 61 =
  1,  						// ASCII 62 >
  76, 						// ASCII 63 ?
  69, 						// ASCII 64 @
  6,  						// ASCII 65 A
  17, 						// ASCII 66 B
  21, 						// ASCII 67 C
  9,  						// ASCII 68 D
  2,  						// ASCII 69 E
  20, 						// ASCII 70 F
  11, 						// ASCII 71 G
  16, 						// ASCII 72 H
  4,  						// ASCII 73 I
  30, 						// ASCII 74 J
  13, 						// ASCII 75 K
  18, 						// ASCII 76 L
  7,  						// ASCII 77 M
  5,  						// ASCII 78 N
  15, 						// ASCII 79 O
  22, 						// ASCII 80 P
  27, 						// ASCII 81 Q
  10, 						// ASCII 82 R
  8,  						// ASCII 83 S
  3,  						// ASCII 84 T
  12, 						// ASCII 85 U
  24, 						// ASCII 86 V
  14, 						// ASCII 87 W
  25, 						// ASCII 88 X
  29, 						// ASCII 89 Y
  19, 						// ASCII 90 Z
  1,  						// ASCII 91 [    
  1,  						// ASCII 92 (backslash)
  1,  						// ASCII 93 ]    
  1,  						// ASCII 94 ^    
  77, 						// ASCII 95 _    
  94, 						// ASCII 96 `    
  6,  						// ASCII 97 a
  17, 						// ASCII 98 b
  21, 						// ASCII 99 c
  9,  						// ASCII 100 d
  2,  						// ASCII 101 e
  20, 						// ASCII 102 f
  11, 						// ASCII 103 g
  16, 						// ASCII 104 h
  4,  						// ASCII 105 i
  30, 						// ASCII 106 j
  13, 						// ASCII 107 k
  18, 						// ASCII 108 l
  7,  						// ASCII 109 m
  5,  						// ASCII 110 n
  15, 						// ASCII 111 o
  22, 						// ASCII 112 p
  27, 						// ASCII 113 q
  10, 						// ASCII 114 r
  8,  						// ASCII 115 s
  3,  						// ASCII 116 t
  12, 						// ASCII 117 u
  24, 						// ASCII 118 v
  14, 						// ASCII 119 w
  25, 						// ASCII 120 x
  29, 						// ASCII 121 y
  19  						// ASCII 122 z
};


// Initialization

void
Morse_inner::inner_begin (unsigned long _dot_delay,
			  unsigned long _dash_delay)
{
  if (_dot_delay != 0)
    dot_delay = _dot_delay;

  if (_dash_delay != 0)
    dash_delay = _dash_delay;

#if NO_SERIAL == 0
  Serial.print ("Morse: dot delay = ");
  Serial.print (dot_delay);
  Serial.print (", dash delay = ");
  Serial.println (dash_delay);
#endif
}


// Basic function to send a single character in morse code

void
Morse_inner::send (char c)
{
  unsigned i, p;

  // Send space
  if (c == ' ')
    {
#if NO_SERIAL == 0
      Serial.println ("Morse: space");
#endif
      delay (7*dot_delay) ;
      return;
    }
  
  // Don't do anything if the character is out of range
  if (c < ' ')
    return;

  i = ((byte) c) - ' ' - 1;
  if (i >= sizeof (morsetab))
    return;

  p = morsetab[i];

  // Main algoritm for each morse sign
  for (p = morsetab[i]; p > 1; p >>= 1)
    {
#if NO_SERIAL == 0
      Serial.print ("Morse: c = '");
      Serial.print (c);
      Serial.print ("', ");
      Serial.println ((p & 1) ? "dash" : "dot");
#endif

      on ();
      delay ((p & 1) ? dash_delay : dot_delay);
      off ();
      delay (dot_delay);
    }

#if NO_SERIAL == 0
  Serial.print ("Morse: c = '");
  Serial.print (c);
  Serial.println ("', done");
#endif

  // Letterspace
  delay (2 * dot_delay);
}

// Functions to send an appropriate string as morse code

void
Morse_inner::sendmsg (const char *str)
{
  if (!str)
    return;

  while (*str)
    {
      send (*str++);
    }
}

void
Morse_inner::sendmsg (char *str)
{
  if (!str)
    return;

  while (*str)
    {
      send(*str++);
    }
}


// Morse_led functions
// Initialization

void
Morse_led::begin (int		_led,					// led to flash on/off
		  unsigned long	_dot_delay,				// delay for dots
		  unsigned long	_dash_delay)				// delay for dashes
{
  if (_led >= 0)
    led_pin = _led;

#if NO_SERIAL == 0
  Serial.print ("Morse, led = ");
  Serial.println (led_pin);
#endif

  inner_begin (_dot_delay, _dash_delay);

  // Initialize the led state
  pinMode (led_pin, OUTPUT);
  digitalWrite (led_pin, LOW);
}

// Turn LED on

void
Morse_led::on (void)
{
  digitalWrite (led_pin, HIGH);
}

// Turn LED off

void
Morse_led::off (void)
{
  digitalWrite (led_pin, LOW);
}


// Morse_analog functions
// Initialize

void
Morse_analog::begin (int		_pwm,				// PWM pin to write to
		     uint16_t		_rate,				// Rate to flash pin on/off
		     int		_led,				// Secondary pin to flash
		     unsigned long	_dot_delay,			// Delay for dots
		     unsigned long	_dash_delay)			// Delay for dashes
{
  if (_pwm >= 0)
    pwm_pin = _pwm;

  if (_rate != 0)
    pwm_rate = _rate;

  if (_led >= 0)
    led_pin = _led;

#if NO_SERIAL == 0
  Serial.print ("Morse: analog = ");
  Serial.print (pwm_pin);
  Serial.print (", rate = ");
  Serial.print (pwm_rate);
  Serial.print (", led = ");
  Serial.println (led_pin);
#endif

  inner_begin (_dot_delay, _dash_delay);

  // Initialize the analog pin and led states
  pinMode (pwm_pin, OUTPUT);
  analogWrite (pwm_pin, 0);

  if (led_pin >= 0)
    {
      pinMode (led_pin, OUTPUT);
      digitalWrite (led_pin, LOW);
    }
}

void
Morse_analog::on (void)
{
  if (led_pin >= 0)
    digitalWrite (led_pin, HIGH);

  analogWrite (pwm_pin, pwm_rate);
}

void
Morse_analog::off (void)
{
  if (led_pin >= 0)
    digitalWrite (led_pin, LOW);

  analogWrite (pwm_pin, 0);
}


// Morse_propshield functions

// Initialization
void
Morse_propshield::begin (int		_pwm,				// Pin connected to the DAT
			 uint16_t	_tone,				// Tone to use
			 int		_led,				// Pin (13) blink at the same time as doing the DAT
			 int		_dat,				// Pin to enable speaker
			 int		_flash,				// Pin for reading/writing flash memory
			 int		_neopixel,			// Pin to enable 11/13 as outputs
			 unsigned long	_dot_delay,			// Delay used for dots
			 unsigned long	_dash_delay)			// Delay used for dashes
{
  if (_pwm >= 0)
    pwm_pin = _pwm;

  if (_tone != 0)
    tone = _tone;

  if (_led >= 0)
    led_pin = _led;

  if (_dat >= 0)
    enable_dat_pin = _dat;

  if (_flash >= 0)
    enable_flash_pin = _flash;

  if (_neopixel >= 0)
    enable_neopixel_pin = _neopixel;

#if NO_SERIAL == 0
  Serial.print ("Morse: propshield = ");
  Serial.print (pwm_pin);
  Serial.print (", tone = ");
  Serial.print (tone);
  Serial.print (", led = ");
  Serial.print (led_pin);
  Serial.print (", enable_dat = ");
  Serial.print (enable_dat_pin);
  Serial.print (", enable_flash = ");
  Serial.print (enable_flash_pin);
  Serial.print (", enable_neopixel = ");
  Serial.println (enable_neopixel_pin);
#endif

  inner_begin (_dot_delay, _dash_delay);

  // Initialize the analog pin and led states
  // Guess at the defaults for the enable pins
  pinMode (pwm_pin, OUTPUT);
  analogWrite (pwm_pin, 0);

  if (led_pin >= 0)
    {
      pinMode (led_pin, OUTPUT);
      digitalWrite (led_pin, LOW);
    }

  if (enable_dat_pin >= 0)
    {
      pinMode (enable_dat_pin, OUTPUT);
      digitalWrite (enable_dat_pin, LOW);
    }

  if (enable_flash_pin >= 0)
    pinMode (enable_flash_pin, OUTPUT);

  if (enable_neopixel_pin >= 0)
    pinMode (enable_neopixel_pin, OUTPUT);
}

// Turn DAT speaker on and emit a tone

void
Morse_propshield::on (void)
{
  if (enable_dat_pin >= 0)
    {
      save_dat = digitalRead (enable_dat_pin);
      digitalWrite (enable_dat_pin, HIGH);
    }

  if (enable_flash_pin >= 0)
    {
      save_flash = digitalRead (enable_flash_pin);
      digitalWrite (enable_flash_pin, LOW);
    }

  if (enable_neopixel_pin >= 0)
    {
      save_neopixel = digitalRead (enable_neopixel_pin);
      digitalWrite (enable_neopixel_pin, LOW);
    }

  if (led_pin >= 0)
    digitalWrite (led_pin, HIGH);

  analogWrite (pwm_pin, tone);
}

// Turn DAT speaker off

void
Morse_propshield::off (void)
{
  analogWrite (pwm_pin, 0);

  if (enable_dat_pin >= 0)
    digitalWrite (enable_dat_pin, save_dat);

  if (enable_flash_pin >= 0)
    digitalWrite (enable_flash_pin, save_flash);

  if (enable_neopixel_pin >= 0)
    digitalWrite (enable_neopixel_pin, save_neopixel);

  if (led_pin >= 0)
    digitalWrite (led_pin, LOW);
}


// HISTORY
// $Log: Meissner_Morse.cpp,v $
// Revision 1.5  2022/02/13 01:04:46  michaelmeissner
// Update copyright year.
//
// Revision 1.4  2020/02/04 13:02:18  michaelmeissner
// Update copyright
//
// Revision 1.3  2019/01/14 04:37:47  michaelmeissner
// Update copyright.
//
// Revision 1.2  2016/04/04 15:02:49  michaelmeissner
// Reset prop shield enable pins to their prior state.
//
// Revision 1.1  2016/04/04 03:33:03  michaelmeissner
// Initial version.
//
