// -*- c++ -*-
// Colorwipe from the Adafruit strandtest example:
// https://github.com/adafruit/Adafruit_NeoPixel/blob/master/examples/strandtest/strandtest.ino
// this code was rewritten by Michael Meissner (arduino@the-meissners.org)

// Copyright (C) 2015-2022, Michael Meissner (arduino@the-meissners.org)
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef MEISSNER_NEOPIXEL_COLORWIPE_H
#define MEISSNER_NEOPIXEL_COLORWIPE_H	1

#include <Meissner_Config.h>
#include <Adafruit_NeoPixel.h>
#include <Meissner_Neopixel.h>
#include <Meissner_Delay.h>

// #define COLORWIPE_DEBUG	1				// define to enable debugging

const unsigned long	COLORWIPE_DELAY		 = 50;		// delay between turning on LEDs
const Neopixel_power_t	COLORWIPE_BRIGHTNESS	 = 30;		// max brightness for color
const Neopixel_iter_t	COLORWIPE_MIN_ITERATIONS = 4;		// min # of iterations
const Neopixel_iter_t	COLORWIPE_MAX_ITERATIONS = 16;		// max # of iterations

class Neopixel_colorwipe : Neopixel_action {
 private:
  Neopixel_mask_t	current_mask;				// current neopixel mask
  Neopixel_rgb_t	current_color;				// current color

 public:
  // constructor/destructor
  Neopixel_colorwipe (Neopixel_power_t	bright		= COLORWIPE_BRIGHTNESS,
		      Neopixel_mask_t	mask		= NEOPIXEL_MASK_NONE,
		      Neopixel_iter_t	min_iter	= COLORWIPE_MIN_ITERATIONS,
		      Neopixel_iter_t	max_iter	= COLORWIPE_MAX_ITERATIONS,
		      unsigned long	delay_led	= COLORWIPE_DELAY);

  ~Neopixel_colorwipe (void);

  // begin function to initialize everything
  void begin (Neopixel_object  *neo,
	      Neopixel_power_t	bright			= 0,
	      Neopixel_mask_t	mask			= NEOPIXEL_MASK_NONE,
	      Neopixel_iter_t	min_iter		= 0,
	      Neopixel_iter_t	max_iter		= 0,
	      unsigned long	delay_led		= 0);

  // Function to set up the actions, possibly setting iterations or brightness levels
  void start (Neopixel_iter_t  iter   = 0,
	      Neopixel_power_t bright = 0);

  // Function called from the main loop function to possibly do the next action.
  // Return false, when all of the current actions are finished.
  // If do_show_p is not a NULL pointer, the function will not call show, but
  // instead set *do_show_p to true.  It is assumed that the user has set
  // *do_show_p  to false before the call.
  bool loop (bool *do_show_p = NULL);

  // Return a string giving the name of the action for debugging
  const char *name (void)
  {
    return "Colorwipe";
  }
};

#endif	/* MEISSNER_NEOPIXEL_COLORWIPE_H */


// HISTORY
// $Log: Meissner_Neopixel_Colorwipe.h,v $
// Revision 1.7  2022/02/13 01:00:34  michaelmeissner
// Update copyright year.
//
// Revision 1.6  2020/01/28 04:07:02  michaelmeissner
// Update copyright year.
//
// Revision 1.5  2019/01/14 04:40:29  michaelmeissner
// Update copyright.
//
// Revision 1.4  2016/03/21 14:02:45  michaelmeissner
// Update copyright year.
//
// Revision 1.3  2015/02/02 03:31:35  michaelmeissner
// Update comment.
//
// Revision 1.2  2015/02/02 03:22:33  michaelmeissner
// Add meissner copyright and notice about it being rewritten.
//
// Revision 1.1  2015/02/02 03:18:54  michaelmeissner
// Initial version.
//
