// -*- arduino -*-
// Simple pattern, to fill a ring with a solid color, and after awhile go on to
// the next color.  The idea is to have a simple pattern that is not
// distracting to people like patterns that chase or choose random pixels do
//
// Copyright (C) 2015-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef MEISSNER_NEOPIXEL_SOLID_COLOR_H
#define MEISSNER_NEOPIXEL_SOLID_COLOR_H	1

#include <Meissner_Config.h>
#include <Adafruit_NeoPixel.h>
#include <Meissner_Neopixel.h>
#include <Meissner_Delay.h>

// Enable tracing to the Serial device
// #define SOLID_COLOR_DEBUG	1

// Various tunings and constants
const unsigned long	SOLID_COLOR_DELAY		= 3000;			// timeout to keep the curent color
const Neopixel_iter_t	SOLID_COLOR_MIN_ITERATIONS	= 2;			// min # of iterations before going to the next pattern
const Neopixel_iter_t	SOLID_COLOR_MAX_ITERATIONS	= 10;			// max # of iterations before going to the next pattern
const Neopixel_power_t	SOLID_COLOR_BRIGHTNESS		= DEFAULT_BRIGHTNESS;	// max brightness to use

class Neopixel_solid_color : Neopixel_action {
 private:
  size_t		current_color;			// current color index

 public:
  // constructor, destructor
  Neopixel_solid_color (Neopixel_iter_t	 max_iter	= SOLID_COLOR_MAX_ITERATIONS,
			Neopixel_iter_t	 min_iter	= SOLID_COLOR_MIN_ITERATIONS,
			Neopixel_power_t bright		= SOLID_COLOR_BRIGHTNESS,
			unsigned long	 delay_color	= SOLID_COLOR_DELAY);

  ~Neopixel_solid_color (void);

  // Setup for solid color
  void begin (Neopixel_object  *neo,
	      Neopixel_power_t	bright			= 0,
	      Neopixel_iter_t	max_iter		= 0,
	      Neopixel_iter_t	min_iter		= 0,
	      unsigned long	delay_color		= 0);


  // Function to set up the actions, possibly setting iterations or brightness levels
  void start (Neopixel_iter_t iter			= 0,
	      Neopixel_power_t bright			= 0);

  // Function called from the main loop function to possibly do the next
  // action.  Return false, when all of the current actions are finished.  If
  // do_show_p is not a NULL pointer, the function will not call show, but
  // instead set *do_show_p to true.  It is assumed that the user has set
  // *do_show_p to false before the call.
  bool loop (bool *do_show_p = NULL);

  // Return a string giving the name of the action for debugging
  const char *name (void)
  {
    return "Solid_Color";
  }
};

#endif	/* MEISSNER_NEOPIXEL_SOLID_COLOR_H */


// HISTORY
// $Log: Meissner_Neopixel_Solid_Color.h,v $
// Revision 1.8  2022/02/27 05:04:09  michaelmeissner
// Update setting brightness.
//
// Revision 1.7  2022/02/13 01:02:22  michaelmeissner
// Update copyright year.
//
// Revision 1.6  2020/01/28 04:09:09  michaelmeissner
// Update copyright year.
//
// Revision 1.5  2019/01/14 04:43:09  michaelmeissner
// Update copyright.
//
// Revision 1.4  2016/04/03 22:49:26  michaelmeissner
// Make (C) in copyright be upper case.
//
// Revision 1.3  2016/03/21 14:05:17  michaelmeissner
// Update copyright year.
//
// Revision 1.2  2015/02/01 15:19:50  michaelmeissner
// Assume do_show_p is set to false before the call.
//
// Revision 1.1  2015/01/16 15:19:02  michaelmeissner
// Initial version.
//
