// -*- c++ -*-
// Theaterchase from the Adafruit strandtest example:
// https://github.com/adafruit/Adafruit_NeoPixel/blob/master/examples/strandtest/strandtest.ino
// this code was rewritten by Michael Meissner (arduino@the-meissners.org)

// Copyright (C) 2015-2022, Michael Meissner (arduino@the-meissners.org)
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef MEISSNER_NEOPIXEL_THEATER_CHASE_H
#define MEISSNER_NEOPIXEL_THEATER_CHASE_H	1

#include <Meissner_Config.h>
#include <Adafruit_NeoPixel.h>
#include <Meissner_Neopixel.h>
#include <Meissner_Delay.h>

// #define THEATER_CHASE_DEBUG	1				// define to enable debugging

const unsigned long	THEATER_CHASE_DELAY		= 50;	// delay between turning on LEDs
const Neopixel_power_t	THEATER_CHASE_BRIGHTNESS	= 30;	// max brightness for color
const Neopixel_iter_t	THEATER_CHASE_MIN_ITERATIONS	= 10;	// min # of iterations
const Neopixel_iter_t	THEATER_CHASE_MAX_ITERATIONS	= 40;	// max # of iterations
const uint8_t		THEATER_CHASE_MAX_OFFSET	= 3;	// max offset for theater iterations

typedef enum {
  THEATER_CHASE_WHITE,						// all white
  THEATER_CHASE_RED,						// red
  THEATER_CHASE_BLUE						// blue
} Theater_chase_color_t;

class Neopixel_theater_chase : Neopixel_action {
 private:
  Neopixel_mask_t	current_mask;				// current neopixel mask
  Neopixel_rgb_t	current_color;				// current color
  Theater_chase_color_t	state;					// what color state we are in
  uint8_t		offset;					// offset we are starting light chase at (0..2)

 public:
  // constructor/destructor
  Neopixel_theater_chase (Neopixel_power_t bright	= THEATER_CHASE_BRIGHTNESS,
			  Neopixel_mask_t  mask		= NEOPIXEL_MASK_NONE,
			  Neopixel_iter_t  min_iter	= THEATER_CHASE_MIN_ITERATIONS,
			  Neopixel_iter_t  max_iter	= THEATER_CHASE_MAX_ITERATIONS,
			  unsigned long    delay_led	= THEATER_CHASE_DELAY);

  ~Neopixel_theater_chase (void);

  // begin function to initialize everything
  void begin (Neopixel_object  *neo,
	      Neopixel_power_t	bright			= 0,
	      Neopixel_mask_t	mask			= NEOPIXEL_MASK_NONE,
	      Neopixel_iter_t	min_iter		= 0,
	      Neopixel_iter_t	max_iter		= 0,
	      unsigned long	delay_led		= 0);

  // Function to set up the actions, possibly setting iterations or brightness levels
  void start (Neopixel_iter_t  iter   = 0,
	      Neopixel_power_t bright = 0);

  // Function called from the main loop function to possibly do the next action.
  // Return false, when all of the current actions are finished.
  // If do_show_p is not a NULL pointer, the function will not call show, but
  // instead set *do_show_p to true.  It is assumed that the user has set
  // *do_show_p  to false before the call.
  bool loop (bool *do_show_p = NULL);

  // Return a string giving the name of the action for debugging
  const char *name (void)
  {
    return "Theater_Chase";
  }
};

#endif	/* MEISSNER_NEOPIXEL_THEATER_CHASE_H */


// HISTORY
// $Log: Meissner_Neopixel_Theater_Chase.h,v $
// Revision 1.6  2022/02/13 01:02:41  michaelmeissner
// Update copyright year.
//
// Revision 1.5  2020/01/28 04:14:11  michaelmeissner
// Update copyright year
//
// Revision 1.4  2019/01/14 04:43:43  michaelmeissner
// Update copyright.
//
// Revision 1.3  2016/03/21 14:06:00  michaelmeissner
// Update copyright year.
//
// Revision 1.2  2015/02/02 13:54:42  michaelmeissner
// Bump up # of iterations.
//
// Revision 1.1  2015/02/02 04:11:35  michaelmeissner
// Initial version.
//
