// -*- arduino -*-
// Meissner random support file
//
// Copyright (C) 2015-2022, Michael Meissner (arduino@the-meissners.org)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#ifndef MEISSNER_RANDOM_H
#define MEISSNER_RANDOM_H	1

#include <stddef.h>
#include <stdlib.h>
#include <inttypes.h>

#if defined(ARDUINO) && ARDUINO >= 100
#include "Arduino.h"

#else
#include "WProgram.h"
#include "WConstants.h"
#endif

#include <Meissner_Config.h>

#if USE_EEPROM_LIB
#include <Meissner_Eeprom.h>
#endif

#if USE_EEPROM
#include <EEPROM.h>
#endif

// Set the random seed, possibly using EEPROM to save the seed across power cycles
extern void set_random_seed (bool use_eepom = false);

#define RANDOM_MAX_RETRIES	5
extern int32_t random_unique (int32_t low,
			      int32_t high,
			      int32_t current,
			      ssize_t retries = RANDOM_MAX_RETRIES);

#endif	/* MEISSNER_RANDOM_H */


// HISTORY
// $Log: Meissner_Random.h,v $
// Revision 1.9  2022/02/13 01:03:23  michaelmeissner
// Update copyright year.
//
// Revision 1.8  2019/01/14 02:19:23  michaelmeissner
// Update copyright.
//
// Revision 1.7  2016/08/10 14:49:24  michaelmeissner
// Default random_unique retries to 5.
//
// Revision 1.6  2016/08/10 14:44:26  michaelmeissner
// Add random_unique function.
//
// Revision 1.5  2016/04/03 22:46:48  michaelmeissner
// Make (C) in copyright be upper case.
//
// Revision 1.4  2016/03/21 14:06:44  michaelmeissner
// Update copyright year.
//
// Revision 1.3  2015/11/25 12:55:06  michaelmeissner
// If we aren't supporting the Eeprom library, don't pull in the include files.
//
// Revision 1.2  2015/01/10 03:20:41  michaelmeissner
// Relicense under the MIT copyright so that we can link in neopixel patterns written by others.
//
// Revision 1.1  2015/01/05 14:58:37  michaelmeissner
// Initial version.
//
