// Uncanny Eyes moved to library format by Michael Meissner.
//
// This particular file (Uncanny_Eyes.cpp) was written to move the Uncanny Eyes
// code to library form and it provides any necessary common functions.
//
// Originally the code was used in the Uncanny Eyes library descends from the
// uncanny eye example in the Adafruit learning system.  Uncanny Eyes ran on
// the Teensy 3.1 and 3.2 boards.
// https://learn.adafruit.com/animated-electronic-eyes/software
//
// Written by Phillip Burgess (Paint Your Dragon)
// With code for Teensys borrowed from the ILI9488_t3 library by Paul Stoffregen.
//
// This code has been adapted and used as examples in the ST7735_t3 driver in
// the Teensydunio releases.
//
//	Original Uncanny Eyes adapted for ST7735_t3 for 128x128 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes7735
//
//	Uncanny Eyes adapted for Teensy 4.x for 240x240 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes_async_st7789_240x240
//
// It was then adapted to the GC9A01A_t3n driver for the 240x240 round
// displays:
//
//	examples/uncannyEyes7735
//	https://github.com/mjs513/GC9A01A_t3n
//
// Some of the people who have modified these files include:
//
//	Phillip Burgess (original author of Uncanny Eyes)
//	Paul Stoffregen (creator of the Teensy line of microprocessors)
//	pjrc.com forum member KurtE
//	pjrc.com forum member mjs512
//	pjrc.com forum member defragster
//	Michael Meissner
//
// --------------------------------------------------------------------------
// Original copyright:
// Uncanny eyes for Adafruit 1.5" OLED (product #1431) or 1.44" TFT LCD
// (#2088).  Works on PJRC Teensy 3.x and on Adafruit M0 and M4 boards
// (Feather, Metro, etc.).  This code uses features specific to these
// boards and WILL NOT work on normal Arduino or other boards!
//
// SEE FILE "config.h" FOR MOST CONFIGURATION (graphics, pins, display type,
// etc).  Probably won't need to edit THIS file unless you're doing some
// extremely custom modifications.
//
// Adafruit invests time and resources providing this open source code,
// please support Adafruit and open-source hardware by purchasing products
// from Adafruit!
//
// Written by Phil Burgess / Paint Your Dragon for Adafruit Industries.
// MIT license.  SPI FIFO insight from Paul Stoffregen's ILI9341_t3 library.
// Inspired by David Boccabella's (Marcwolf) hybrid servo/OLED eye concept.
//--------------------------------------------------------------------------

#include <Arduino.h>
#include <SPI.h>
#include <Adafruit_GFX.h>
#include <Uncanny_Eyes.h>


#if defined(__IMXRT1062__)	// Teensy 4.0 and 4.1

// Provide memory checking debug support.
// from the linker
// extern unsigned long _stextload;
extern unsigned long _stext;
extern unsigned long _etext;

// extern unsigned long _sdataload;
extern unsigned long _sdata;
extern unsigned long _edata;
extern unsigned long _sbss;
extern unsigned long _ebss;

// extern unsigned long _flexram_bank_config;
extern unsigned long _estack;

void DumpMemoryInfo(void) {
  uint32_t flexram_config = IOMUXC_GPR_GPR17;
  Serial.printf ("IOMUXC_GPR_GPR17: 0x%lx "
		 "IOMUXC_GPR_GPR16: 0x%lx "
		 "IOMUXC_GPR_GPR14: 0x%lx\n",
		 (unsigned long) flexram_config,
		 (unsigned long) IOMUXC_GPR_GPR16,
		 (unsigned long) IOMUXC_GPR_GPR14);

  Serial.printf ("Initial Stack pointer: 0x%lx\n",
		 (unsigned long) &_estack);

  uint32_t dtcm_size = 0;
  uint32_t itcm_size = 0;

  for (; flexram_config; flexram_config >>= 2) {
    if ((flexram_config & 0x3) == 0x2)
      dtcm_size += 32768;

    else if ((flexram_config & 0x3) == 0x3)
      itcm_size += 32768;
  }

  Serial.printf ("ITCM allocated: %lu  DTCM allocated: %lu\n",
		 (unsigned long) itcm_size,
		 (unsigned long) dtcm_size);

  Serial.printf ("ITCM init range: 0x%lx - 0x%lx Count: %lu\n",
		 (unsigned long) &_stext,
		 (unsigned long) &_etext,
		 (unsigned long) &_etext - (unsigned long) &_stext);

  Serial.printf ("DTCM init range: 0x%lx - 0x%lx Count: %lu\n",
		 (unsigned long) &_sdata,
		 (unsigned long) &_edata,
		 (unsigned long) &_edata - (unsigned long) &_sdata);

  Serial.printf ("DTCM cleared range: 0x%lx - 0x%lx Count: %lu\n",
		 (unsigned long) &_sbss,
		 (unsigned long) &_ebss,
		 (unsigned long) &_ebss - (unsigned long) &_sbss);

#if 0
  Serial.printf ("Now fill rest of DTCM with known pattern (0x%lx - 0x%lx\n",
		 (unsigned long) (&_ebss + 1),
		 (unsigned long) (&itcm_size - 10));

  Serial.flush();

  // Guess of where it is safe to fill memory... Maybe address of last
  // variable we have defined - some slop...
  for (uint32_t *pfill = (&_ebss + 32); pfill < (&itcm_size - 10); pfill++) {
    *pfill = 0x01020304;  // some random value
  }
#endif
}

void EstimateStackUsage(void)
{
  uint32_t *pmem = (&_ebss + 32);
  while (*pmem == 0x01020304)
    pmem++;

  Serial.printf("Estimated max stack usage: %ld\n",
		(unsigned long)&_estack - (unsigned long)pmem);
}

#else	// Not Teensy 4.0 or 4.1
void DumpMemoryInfo(void)
{
}

void EstimateStackUsage(void)
{
}
#endif	// Teensy 4.x support


// HISTORY
// $Log: Uncanny_Eyes.cpp,v $
// Revision 1.3  2022/09/17 15:02:38  michaelmeissner
// Remove DEBUG_MEMORY test (caller now does the test).
//
// Revision 1.2  2022/09/17 14:39:52  michaelmeissner
// Implement most functionality
//
// Revision 1.1  2022/09/17 10:29:05  michaelmeissner
// Initial version
//
