// Uncanny Eyes moved to library format by Michael Meissner.
//
// This particular file (Uncanny_Eyes.h) was written to move the Uncanny Eyes
// code to library form.
//
// Originally the code was used in the Uncanny Eyes library descends from the
// uncanny eye example in the Adafruit learning system.  Uncanny Eyes ran on
// the Teensy 3.1 and 3.2 boards.
// https://learn.adafruit.com/animated-electronic-eyes/software
//
// Written by Phillip Burgess (Paint Your Dragon)
// With code for Teensys borrowed from the ILI9488_t3 library by Paul Stoffregen.
//
// This code has been adapted and used as examples in the ST7735_t3 driver in
// the Teensydunio releases.
//
//	Original Uncanny Eyes adapted for ST7735_t3 for 128x128 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes7735
//
//	Uncanny Eyes adapted for Teensy 4.x for 240x240 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes_async_st7789_240x240
//
// It was then adapted to the GC9A01A_t3n driver for the 240x240 round
// displays:
//
//	examples/uncannyEyes7735
//	https://github.com/mjs513/GC9A01A_t3n
//
// Some of the people who have modified these files include:
//
//	Phillip Burgess (original author of Uncanny Eyes)
//	Paul Stoffregen (creator of the Teensy line of microprocessors)
//	pjrc.com forum member KurtE
//	pjrc.com forum member mjs512
//	pjrc.com forum member defragster
//	Michael Meissner
//
// --------------------------------------------------------------------------
// Original copyright:
// Uncanny eyes for Adafruit 1.5" OLED (product #1431) or 1.44" TFT LCD
// (#2088).  Works on PJRC Teensy 3.x and on Adafruit M0 and M4 boards
// (Feather, Metro, etc.).  This code uses features specific to these
// boards and WILL NOT work on normal Arduino or other boards!
//
// SEE FILE "config.h" FOR MOST CONFIGURATION (graphics, pins, display type,
// etc).  Probably won't need to edit THIS file unless you're doing some
// extremely custom modifications.
//
// Adafruit invests time and resources providing this open source code,
// please support Adafruit and open-source hardware by purchasing products
// from Adafruit!
//
// Written by Phil Burgess / Paint Your Dragon for Adafruit Industries.
// MIT license.  SPI FIFO insight from Paul Stoffregen's ILI9341_t3 library.
// Inspired by David Boccabella's (Marcwolf) hybrid servo/OLED eye concept.
//--------------------------------------------------------------------------

#ifndef HAVE_UNCANNY_EYES_H
#define HAVE_UNCANNY_EYES_H	1

#include <Arduino.h>
#include <SPI.h>
#include <Adafruit_GFX.h>

// Maximum # of eyes to define.
#define MAX_EYES	2

// Information for each eye display.
typedef struct {
  //int8_t  select;		// pin numbers for each eye's screen select line
  int8_t  cs;			// Display Chip select pin (or -1 if none).
  int8_t  dc;			// Display D/C pin
  int8_t  mosi;			// SPI MOSI pin
  int8_t  sck;			// SPI SCK pin
  int8_t  rst;			// Display reset pin
  int8_t  wink;			// Display wink button (or -1 if none)
  uint8_t rotation;		// Display rotation to use
  uint8_t init_option;		// Display option for Initialization
} eyeInfo_t;

extern const eyeInfo_t eyeInfo[];
extern const size_t NUM_EYES;

// Information for a single graphics image in memory that has uint16_t element
class Image16 {
 private:
  unsigned        height;		// height in pixels
  unsigned        width;		// width in pixels
  const uint16_t *data;			// in memory images (height x width)

 public:
  // Constructor
  Image16 (unsigned        _height,
	   unsigned        _width,
	   const uint16_t *_data)
    : height (_height),
      width  (_width),
      data   (_data)
    {
    }

  // Destructor
  ~Image16 (void)
    {
    }

  // Return a particular pixel
  uint16_t get (unsigned h, unsigned w)
  {
    return data[ (h * height) + w ];
  }

  // Return width and height
  unsigned get_width  (void) { return width;  }
  unsigned get_height (void) { return height; }
};

// Information for a single graphics image in memory that has uint8_t element
class Image8 {
 private:
  unsigned       height;		// height in pixels
  unsigned       width;			// width in pixels
  const uint8_t *data;			// in memory images (height x width)

 public:
  // Constructor
  Image8 (unsigned       _height,
	  unsigned       _width,
	  const uint8_t *_data)
    : height (_height),
      width  (_width),
      data   (_data)
    {
    }

  // Destructor
  ~Image8 (void)
    {
    }

  // Return a particular pixel
  uint8_t get (unsigned h, unsigned w)
  {
    return data[ (h * height) + w ];
  }

  // Return width and height
  unsigned get_width  (void) { return width;  }
  unsigned get_height (void) { return height; }
};

// Combined eye image information
struct Image_combined {
  const char *eye_name;
  Image16    *sclera;
  Image16    *iris;
  Image8     *upper;
  Image8     *lower;
  Image16    *polar;
  int         sclera_height;
  int         sclera_width;
  int         iris_min;
  int         iris_max;
  int         iris_height;
  int         iris_width;
  int         iris_map_height;
  int         iris_map_width;
  int         screen_height;
  int         screen_width;
};

// Debug support.
extern void DumpMemoryInfo     (void);
extern void EstimateStackUsage (void);

// Image information functions.
extern Image_combined *image_default_large   (bool symmetrical = false);
extern Image_combined *image_default_128x128 (bool symmetrical = false);

#endif	/*  HAVE_UNCANNY_EYES_H.  */


// HISTORY
// $Log: Uncanny_Eyes.h,v $
// Revision 1.5  2022/10/03 03:16:11  michaelmeissner
// Move SPI_FREQ to Uncanny_Eyes_240x240.h.
//
// Revision 1.4  2022/10/02 23:25:20  michaelmeissner
// Add image_default_128x128.
//
// Revision 1.3  2022/09/17 15:11:11  michaelmeissner
// Remove extern const int/bool since we can only build one driver, and these should be defined in the .ino file.
//
// Revision 1.2  2022/09/17 14:39:52  michaelmeissner
// Implement most functionality
//
// Revision 1.1  2022/09/17 10:29:05  michaelmeissner
// Initial version
//
