// Uncanny Eyes default pins
//
// Define to be 1 before including this file:
//
//	NO_RIGHT_CS	-- Do not define the right CS pin (for cheaper 240x24 displays)
//	NO_LEFT_CS	-- Do not define the left  CS pin (for cheaper 240x24 displays)
//	NO_CS		-- Do not define either    CS pin (for cheaper 240x24 displays)
//	NO_RIGHT_WINK	-- Do not define the right wink pin
//	NO_LEFT_WINK	-- Do not define the left  wink pin
//	NO_WINK		-- Do not define either    wink pin
//	SINGLE_EYE	-- Only define pins for a single eye

#ifndef UNCANNY_EYES_DEFAULT_EYES_H
#define UNCANNY_EYES_DEFAULT_EYES_H	1

#if !defined(__arm__) || !defined(CORE_TEENSY)
#error "At present, the defaults are only set up for Teensys"
#endif

// Pick up the default SPI pins from Meissner_Config.h.
#ifndef MEISSNER_CONFIG_H
#include <Meissner_Config.h>
#endif


#if PROCESSOR_TEENSY_4_X
// Teensy 4.0 or 4.1
#if (NO_CS != 0) || (NO_LEFT_CS != 0)
#define L_CS	-1			// left display, no CS pin
#else
#define L_CS	SPI0_CS_A		// left display, CS pin,          currently 22
#endif	/* left CS pin.  */

#define L_DC	SPI0_DC			// left display, D/C pin,	  currently  9
#define L_MOSI	SPI0_MOSI		// left display, SPI0 MOSI pin,   pin       11
#define L_SCK	SPI0_SCLK		// left display, SPI0 clock pin,  pin       13
#define L_RST	SPI0_RESET		// left display, reset pin,       currently  5

#if (NO_WINK != 0) || (NO_LEFT_WINK != 0)
#define L_WINK	-1			// left display, no wink pin
#else
#define L_WINK	31			// left display, wink on pin 31
#endif	/* left wink pin.  */

// SPI1
#if !SINGLE_EYE
#if (NO_CS != 0) || (NO_RIGHT_CS != 0)
#define R_CS	-1			// right display, no CS pin
#else
#define R_CS	SPI1_CS_A		// right display, CS pin,         currently  0
#endif	/* right CS pin.  */

#define R_DC	SPI1_DC			// right display, D/C pin,        currently 24
#define R_MOSI	SPI1_MOSI		// right display, SPI1 MOSI pin,  pin       26
#define R_SCK	SPI1_SCLK		// right display, SPI1 clock pin, pin       27
#define R_RST	SPI1_RESET		// right display, reset pin,      currently 25

#if (NO_WINK != 0) || (NO_RIGHT_WINK != 0)
#define R_WINK	-1			// right display, no wink pin
#else
#define R_WINK	32			// right display, wink on pin 32
#endif	/* right wink pin.  */
#endif	/* SINGLE_EYE.  */


#elif PROCESSOR_TEENSY_3_X
// Teensy 3.2, 3.5, or 3.6.
// Assume the Teensy 3.x processors will use the 128x128 displays and the original code.
// The two displays will be on the same SPI bus, and use common D/C and reset pins.

#define L_CS	SPI0_CS_A		// left display, CS pin,          currently 22
#define L_DC	SPI0_DC			// left display, D/C pin,         currently  9
#define L_MOSI	SPI0_MOSI		// left display, MOSI pin,        pin       11
#define L_SCK	SPI0_SCLK		// left display, clock pin,       pin       13
#define L_RST	SPI0_RESET		// left display, reset pin,       currently  5
#define L_WINK	-1			// left display, no wink pin for now

#if !SINGLE_EYE
#define R_CS	SPI0_CS_B		// right display, CS pin,         currently 10
#define R_DC	SPI0_DC			// right display, D/C pin,        currently  9
#define R_MOSI	SPI0_MOSI		// right display, MOSI pin,       pin       11
#define R_SCK	SPI0_SCLK		// left display, clock pin,       pin       13
#define R_RST	SPI0_RESET		// left display, reset pin,       current    5
#define R_WINK	-1			// left display, no wink pin for now
#endif	/* SINGLE_EYE  */

#else
#error "Only Teensy 3.x or 4.x supported for now."
#endif	/* Teensy 4.x or 3.x.  */


// INPUT SETTINGS (for controlling eye motion) -----------------------------

// JOYSTICK_X_PIN and JOYSTICK_Y_PIN specify analog input pins for manually
// controlling the eye with an analog joystick.  If set to -1 or if not
// defined, the eye will move on its own.
//
// IRIS_PIN speficies an analog input pin for a photocell to make pupils
// react to light (or potentiometer for manual control).  If set to -1 or
// if not defined, the pupils will change on their own.
//
// BLINK_PIN specifies an input pin for a button (to ground) that will
// make any/all eyes blink.  If set to -1 or if not defined, the eyes will
// only blink if AUTOBLINK is defined, or if the eyeInfo[] table above
// includes wink button settings for each eye.

// Provide defaults, but allow the including .ino file to override these definitions.

#ifndef JOYSTICK_X_PIN
const int	JOYSTICK_X_PIN		= -1;		// Analog pin for eye horizontal position (else auto)
#endif

#ifndef JOYSTICK_Y_PIN
const int	JOYSTICK_Y_PIN		= -1;		// Analog pin for eye vertical position (else auto)
#endif

#ifndef JOYSTICK_X_FLIP
const bool	JOYSTICK_X_FLIP		= false;	// If true, reverse stick X axis
#endif

#ifndef JOYSTICK_Y_FLIP
const bool	JOYSTICK_Y_FLIP		= false;	// If true, reverse stick Y axis
#endif

#ifndef TRACKING
const bool	TRACKING		= false;	// If true, eyelid tracks pupil
#endif

#ifndef AUTOBLINK
const bool	AUTOBLINK		= false;	// If false, eyes also blink autonomously
#endif

#ifndef BLINK_PIN
const int	BLINK_PIN		= 3;		// Pin for manual blink button (BOTH eyes)
#endif

#ifndef LIGHT_PIN
const int	LIGHT_PIN		= -1;		// Photocell or potentiometer (else auto iris) or -1
#endif

#ifndef LIGHT_PIN_FLIP
const bool	LIGHT_PIN_FLIP		= false;	// If true, reverse reading from dial/photocell
#endif

#ifndef LIGHT_MIN
const int	LIGHT_MIN		= 0;		// Lower reading from sensor
#endif

#ifndef LIGHT_MAX
const int	LIGHT_MAX		= 1023;		// Upper reading from sensor
#endif

#ifndef LIGHT_CURVE
const bool	LIGHT_CURVE		= false;	// Apply gamma curve to sensor input?
#endif

#ifndef IRIS_SMOOTH
const bool	IRIS_SMOOTH		= true;		// If true, filter input from IRIS_PIN
#endif

#ifndef DISPLAY_BACKLIGHT
const int	DISPLAY_BACKLIGHT	= -1;		// Pin to control display backlight.
#endif

#ifndef BACKLIGHT_MAX
const int	BACKLIGHT_MAX		= 255;		// Maximum value for display backlight.
#endif

#ifndef DEBUG_MEMORY
const bool	DEBUG_MEMORY		= false;	// Whether to turn on memory debugging.
#endif

// If using a SINGLE EYE, you might want this next line enabled, which
// uses a simpler "football-shaped" eye that's left/right symmetrical.
// Default shape includes the caruncle, creating distinct left/right eyes.
// Otherwise your choice, standard is asymmetrical
#ifndef SYMMETRICAL_EYELID
#if SINGLE_EYE
const bool	SYMMETRICAL_EYELID	= true;
#else
const bool	SYMMETRICAL_EYELID	= false;
#endif
#endif

#endif	/* UNCANNY_EYES_DEFAULT_EYES_H  */

// History
// $Log: Uncanny_Eyes_Default_Eyes.h,v $
// Revision 1.4  2022/10/02 22:36:16  michaelmeissner
// Add #ifdef guard code.
//
// Revision 1.3  2022/10/02 21:50:26  michaelmeissner
// Set SYMMETRICAL_EYELID true if single eye.
//
// Revision 1.2  2022/10/02 21:29:37  michaelmeissner
// Move definitions of input settings to Uncanny_Eyes_Default_Eyes.h.
//
// Revision 1.1  2022/10/02 05:55:44  michaelmeissner
// Initial version.
//

