// Uncanny Eyes moved to library format by Michael Meissner.
//
// This file (Uncanny_Eyes_GC9A01A.cpp) implements Uncanny Eyes for the 1.28"
// 240x240 round displays.  Some of these displays found via a google search
// include:
//
//	https://www.waveshare.com/1.28inch-lcd-module.htm
//	https://shop.pimoroni.com/products/1-3-spi-colour-round-lcd-240x240-breakout?variant=39295294341203
//	https://www.amazon.com/Display-Interface-Resolution-Instrument-Equipment/dp/B08G7Y87VY
//	https://www.amazon.com/1-28inch-Display-Resolution-Interface-Raspberry/dp/B08VGT2T42?th=1
//	https://www.buydisplay.com/1-28-inch-tft-lcd-display-240x240-round-circle-screen-for-smart-watch
//
// Originally the code was used in the Uncanny Eyes library descends from the
// uncanny eye example in the Adafruit learning system.  Uncanny Eyes ran on
// the Teensy 3.1 and 3.2 boards.
// https://learn.adafruit.com/animated-electronic-eyes/software
//
// Written by Phillip Burgess (Paint Your Dragon)
// With code for Teensys borrowed from the ILI9488_t3 library by Paul Stoffregen.
//
// This code has been adapted and used as examples in the ST7735_t3 driver in
// the Teensydunio releases.
//
//	Original Uncanny Eyes adapted for ST7735_t3 for 128x128 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes7735
//
//	Uncanny Eyes adapted for Teensy 4.x for 240x240 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes_async_st7789_240x240
//
// It was then adapted to the GC9A01A_t3n driver for the 240x240 round
// displays:
//
//	examples/uncannyEyes7735
//	https://github.com/mjs513/GC9A01A_t3n
//
// Some of the people who have modified these files include:
//
//	Phillip Burgess (original author of Uncanny Eyes)
//	Paul Stoffregen (creator of the Teensy line of microprocessors)
//	pjrc.com forum member KurtE
//	pjrc.com forum member mjs512
//	pjrc.com forum member defragster
//	Michael Meissner
//
// --------------------------------------------------------------------------
// Original copyright:
// Uncanny eyes for Adafruit 1.5" OLED (product #1431) or 1.44" TFT LCD
// (#2088).  Works on PJRC Teensy 3.x and on Adafruit M0 and M4 boards
// (Feather, Metro, etc.).  This code uses features specific to these
// boards and WILL NOT work on normal Arduino or other boards!
//
// SEE FILE "config.h" FOR MOST CONFIGURATION (graphics, pins, display type,
// etc).  Probably won't need to edit THIS file unless you're doing some
// extremely custom modifications.
//
// Adafruit invests time and resources providing this open source code,
// please support Adafruit and open-source hardware by purchasing products
// from Adafruit!
//
// Written by Phil Burgess / Paint Your Dragon for Adafruit Industries.
// MIT license.  SPI FIFO insight from Paul Stoffregen's ILI9341_t3 library.
// Inspired by David Boccabella's (Marcwolf) hybrid servo/OLED eye concept.
//--------------------------------------------------------------------------

// Originally this file was supposed to be a .cpp file in the library, but the
// library is not set up to build both ST7789 and GC9A01A drivers in the same
// program.

// Always use async update for 240x240 since we have to use Teensy 4.x
#define USE_ASYNC_UPDATES	1

#include <GC9A01A_t3n.h>

// Types and defines needed for the 240x240 driver.
#define USE_ST7789		0
#define USE_ST7735		0
#define USE_SSD1351		0
#define USE_GC9A01A		1

// Map RGB into uint16_t
#define RGBColor(R, G, B)	GC9A01A_t3n::Color565(R, G, B)

// Type to use for the display
typedef GC9A01A_t3n displayType;

// Command to send to the display
#define DRIVER_CMD		GC9A01A_MADCTL

// Common code
#include <Uncanny_Eyes_240x240.h>


// HISTORY
// $Log: Uncanny_Eyes_GC9A01A.h,v $
// Revision 1.3  2022/10/03 02:28:02  michaelmeissner
// Update comment.
//
// Revision 1.2  2022/10/02 22:38:23  michaelmeissner
// Add USE_{ST7735,SSD1351}.
//
// Revision 1.1  2022/09/17 14:39:52  michaelmeissner
// Implement most functionality
//
