// Uncanny Eyes moved to library format by Michael Meissner.
//
// This file (Uncanny_Eyes_TFT128.h) implements Uncanny Eyes for the 128x128
// square displays that use the ST7735 chipset.
//
// Originally the code was used in the Uncanny Eyes library descends from the
// uncanny eye example in the Adafruit learning system.  Uncanny Eyes ran on
// the Teensy 3.1 and 3.2 boards.
// https://learn.adafruit.com/animated-electronic-eyes/software
//
// Written by Phillip Burgess (Paint Your Dragon)
// With code for Teensys borrowed from the ILI9488_t3 library by Paul Stoffregen.
//
// This code has been adapted and used as examples in the ST7735_t3 driver in
// the Teensydunio releases.
//
//	Original Uncanny Eyes adapted for ST7735_t3 for 128x128 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes7735
//
//	Uncanny Eyes adapted for Teensy 4.x for 240x240 displays:
//	hardware/teensy/avr/libraries/ST7735_t3/examples/uncannyEyes_async_st7789_240x240
//
// It was then adapted to the GC9A01A_t3n driver for the 240x240 round
// displays:
//
//	examples/uncannyEyes7735
//	https://github.com/mjs513/GC9A01A_t3n
//
// Some of the people who have modified these files include:
//
//	Phillip Burgess (original author of Uncanny Eyes)
//	Paul Stoffregen (creator of the Teensy line of microprocessors)
//	pjrc.com forum member KurtE
//	pjrc.com forum member mjs512
//	pjrc.com forum member defragster
//	Michael Meissner
//
// --------------------------------------------------------------------------
// Original copyright:
// Uncanny eyes for Adafruit 1.5" OLED (product #1431) or 1.44" TFT LCD
// (#2088).  Works on PJRC Teensy 3.x and on Adafruit M0 and M4 boards
// (Feather, Metro, etc.).  This code uses features specific to these
// boards and WILL NOT work on normal Arduino or other boards!
//
// SEE FILE "config.h" FOR MOST CONFIGURATION (graphics, pins, display type,
// etc).  Probably won't need to edit THIS file unless you're doing some
// extremely custom modifications.
//
// Adafruit invests time and resources providing this open source code,
// please support Adafruit and open-source hardware by purchasing products
// from Adafruit!
//
// Written by Phil Burgess / Paint Your Dragon for Adafruit Industries.
// MIT license.  SPI FIFO insight from Paul Stoffregen's ILI9341_t3 library.
// Inspired by David Boccabella's (Marcwolf) hybrid servo/OLED eye concept.
//--------------------------------------------------------------------------

// Originally this file was supposed to be a .cpp file in the library, but the
// library is not set up to build both ST7789 and GC9A01A drivers in the same
// program.

#include <Arduino.h>
#include <SPI.h>
#include <Adafruit_GFX.h>
#include <Uncanny_Eyes.h>

// On Teensy 4.0/4.1 use async update for 128x128 TFT display.  Enable use of
// both SPI devices
//#define USE_ASYNC_UPDATES	1
#define ST77XX_ON_SPI_SPI1	1

// Reduce the SPI Frequency to match the TFT 128x128 displays that we have.
#ifndef SPI_FREQ
  #define SPI_FREQ 48000000	// SPI frequency to use (48 Mhz).
//#define SPI_FREQ 23000000	// SPI frequency to use (23 Mhz).
//#define SPI_FREQ 11000000	// SPI frequency to use (11 Mhz).
#endif


#ifndef __ST7735_t3_H_
#include <ST7735_t3.h>
#endif

// Types and defines needed for the main library and the Uncanny Eyes driver.
// Identify driver to use
#define USE_ST7789		0
#define USE_ST7735		1
#define USE_SSD1351		0
#define USE_GC9A01A		0

// Map RGB into uint16_t
#define RGBColor(R, G, B)	ST7735_t3x::Color565(R, G, B)

// Type to use for the display
typedef ST7735_t3 displayType;

// Command to send to the display
#ifdef ST77XX_MADCTL
#define DRIVER_CMD		ST77XX_MADCTL	// Current TFT library
#else
#define DRIVER_CMD		ST7735_MADCTL	// Older TFT library
#endif

// Common code.  At the moment, use the 240x240 library, but ultimately, we may
// want to use the original code that bypassed the library for the Teensy 3.x.
#include <Uncanny_Eyes_240x240.h>


// HISTORY
// $Log: Uncanny_Eyes_TFT128.h,v $
// Revision 1.4  2022/10/03 03:25:31  michaelmeissner
// Update comment.
//
// Revision 1.3  2022/10/03 03:19:31  michaelmeissner
// Move setting SPI_FREQ to Uncanny_Eyes_TFT128.h.
//
// Revision 1.2  2022/10/03 03:12:14  michaelmeissner
// Add #ifdef guard for ST7735_t3.h; Turn off ASYNC_UPDATES.
//
// Revision 1.1  2022/10/03 02:33:55  michaelmeissner
// Initial version.
//
