#include <Meissner_Config.h>

// Pull in the common pins.
// #define NO_WINK		1
// #define NO_RIGHT_WINK	1
// #define NO_LEFT_WINK		1
// #define NO_CS		1
// #define NO_RIGHT_CS		1
// #define NO_LEFT_CS		1
// #define SINGLE_EYE		1
#include <Uncanny_Eyes_Default_Eyes.h>

#include <Uncanny_Eyes.h>

// Uncanny Eyes for 2 Adafruit 240x240 displays that both have CS pins and use
// the ST7789 chip.
//
// Adafruit 1.3"  240x240: https://www.adafruit.com/product/4313 (tested)
// Adafruit 1.54" 240x240: https://www.adafruit.com/product/3787

// GRAPHICS SETTINGS (appearance of eye) -----------------------------------

// If using a SINGLE EYE, you might want this next line enabled, which
// uses a simpler "football-shaped" eye that's left/right symmetrical.
// Default shape includes the caruncle, creating distinct left/right eyes.
// Otherwise your choice, standard is asymmetrical
//#define SYMMETRICAL_EYELID

// EYE LIST ----------------------------------------------------------------

// This table contains ONE LINE PER EYE.  The table MUST be present with
// this name and contain ONE OR MORE lines.  Each line contains THREE items:
// a pin number for the corresponding TFT/OLED display's SELECT line, a pin
// pin number for that eye's "wink" button (or -1 if not used), and a screen
// rotation value (0-3) for that eye.

#define L_ROT	0			// left  display, rotation
#define L_INIT	0			// left  display, initialization for display with CS pin
#define R_ROT	0			// right display, rotation
#define R_INIT	0			// right display, initialization for display with CS pin

const eyeInfo_t eyeInfo[] = {

  //CS    DC    MOSI    SCK    RST    WINK    ROT    INIT
  { L_CS, L_DC, L_MOSI, L_SCK, L_RST, L_WINK, L_ROT, L_INIT },
  { R_CS, R_DC, R_MOSI, R_SCK, R_RST, R_WINK, R_ROT, R_INIT },
//#endif
};

const size_t	NUM_EYES	= (sizeof eyeInfo / sizeof eyeInfo[0]);
const int	DISPLAY_SIZE	= 240;		// size of the display.


// begin support for playing a sound from program memory
#include <Audio.h>
#include <Wire.h>
#include <SPI.h>
#include <SD.h>
#include <SerialFlash.h>

#include <Audio.h>
#include <Wire.h>
#include <SPI.h>
#include <SD.h>
#include <SerialFlash.h>

// GUItool: begin automatically generated code
AudioPlayMemory		static_sounds;				//xy=100,207
AudioEffectDelay	mono_to_stereo;				//xy=245,207
AudioOutputI2S		audio_shield;				//xy=404,207
AudioControlSGTL5000	sgtl5000;				//xy=404,221
AudioConnection		patchCord1(static_sounds, mono_to_stereo);
AudioConnection		patchCord2(mono_to_stereo, 0, audio_shield, 0);
AudioConnection		patchCord3(mono_to_stereo, 1, audio_shield, 1);
// GUItool: end automatically generated code

#define DO_CACKLE	1
#define DO_CATSCREAM	0
#define DO_GHOUL	1
#define DO_KNOCKING	1
#define DO_SCREECH	0
#define DO_SCREAM	0
#define DO_SCREAM2	1

#if DO_CACKLE
#include <AudioSampleCackle.h>					// 23105 ints
#endif

#if DO_CATSCREAM
#include <AudioSampleCatscream.h>				// 55137 ints
#endif

#if DO_GHOUL
#include <AudioSampleGhoul.h>					// 10513 ints
#endif

#if DO_KNOCKING
#include <AudioSampleKnocking.h>				// 36017 ints
#endif

#if DO_SCREAM
#include <AudioSampleScream.h>					// 7457 ints
#endif

#if DO_SCREAM2
#include <AudioSampleScream2.h>					// 7041 ints
#endif

#if DO_SCREECH
#include <AudioSampleScreech.h>					// 19665 ints
#endif

// Data structure to hold which sounds to play
struct raw_sounds {
  const unsigned int *const	data;				// sounds to play
  const char *const		name;				// name of the sound
  const size_t			size;				// size in bytes of the sound
};

static const struct raw_sounds sounds[] = {
#if DO_CACKLE
  { AudioSampleCackle,		"Cackle",	sizeof (AudioSampleCackle)	},
#endif

#if DO_CATSCREAM
  { AudioSampleCatscream,	"Catscream",	sizeof (AudioSampleCatscream)	},
#endif

#if DO_GHOUL
  { AudioSampleGhoul,		"Ghoul",	sizeof (AudioSampleGhoul)	},
#endif

#if DO_KNOCKING
  { AudioSampleKnocking,	"Knocking",	sizeof (AudioSampleKnocking)	},
#endif

#if DO_SCREAM
  { AudioSampleScream,		"Scream",	sizeof (AudioSampleScream)	},
#endif

#if DO_SCREAM2
  { AudioSampleScream2,		"Scream2",	sizeof (AudioSampleScream2)	},
#endif

#if DO_SCREECH
  { AudioSampleScreech,		"Screech",	sizeof (AudioSampleScreech)	},
#endif

};

const	size_t	num_sounds	= sizeof (sounds) / sizeof (sounds[0]);
static	bool	first_time	= true;
static	bool	sound_seq	= true;
static	size_t	sound_index	= 0;

void
play_memory (void)
{
  bool do_random = false;

  if (first_time)
    {
      first_time = false;
      sound_index = 0;
    }

  // If we only have one sound, there is no choice
  else if (num_sounds == 1)
    sound_index = 0;

  // If we only have two sounds, just alternate between the two
  else if (num_sounds == 2)
    sound_index = (sound_index + 1) & 1;

  // First play sounds in order.
  else if (sound_seq)
    {
      if (sound_index >= num_sounds - 1)
	{
	  sound_seq = false;
	  do_random = true;
	}
      else
	sound_index++;
    }

  else
    do_random = true;

  if (do_random)
    {
      size_t prev_sound = sound_index;
      sound_index = random (0, num_sounds);
      if (prev_sound == sound_index)
	{
	  Serial.printf ("Skip sound %d (%s).\n",
			 (int)sound_index,
			 sounds[sound_index].name);

	  sound_index = (sound_index + 1) % num_sounds;
	}
    }

  Serial.printf ("Play sound %d (%s), %ld bytes.\n",
		 (int)sound_index,
		 sounds[sound_index].name,
		 (long)sounds[sound_index].size);

  static_sounds.play (sounds[sound_index].data);
}


// Include all of the driver code here.
#include <Uncanny_Eyes_ST7789.h>


void loop ()
{
  // Audio support
  if (num_sounds > 0 && (first_time || !static_sounds.isPlaying ()))
    play_memory ();

  inner_loop ();
}

void setup ()
{
  inner_setup (image_default_large ());

  // Audio setup
  // Audio connections require memory to work.  For more
  // detailed information, see the MemoryAndCpuUsage example
  AudioMemory (8);

  // Set up the audio shield.
  sgtl5000.enable ();
  sgtl5000.volume (0.5f);

  // Duplicate the mono sounds from PlayMemory to be stereo
  mono_to_stereo.delay (0, 0);
  mono_to_stereo.delay (1, 0);

  if (num_sounds == 0) {
    Serial.println ("No sounds.\n");

  } else if (num_sounds == 1) {
    Serial.printf ("1 sound found: %s\n", sounds[0].name);

  } else {
    Serial.printf ("%d sounds:", (int)num_sounds);
    for (size_t i = 0; i < num_sounds; i++)
      Serial.printf (" %s", sounds[i].name);

    Serial.println ("");
  }
}


// HISTORY
// $Log: Uncanny_Eyes_ST7789_2eyes_Sound.ino,v $
// Revision 1.6  2022/10/10 07:07:08  michaelmeissner
// Spacing.
//
// Revision 1.5  2022/10/10 07:05:15  michaelmeissner
// Rename audio devices.
//
// Revision 1.4  2022/10/10 07:01:05  michaelmeissner
// Play sounds before doing eyes.
//
// Revision 1.3  2022/10/10 06:55:38  michaelmeissner
// Duplicate mono sound in each speaker; Properly initialize the audio shield.
//
// Revision 1.2  2022/10/07 03:38:20  michaelmeissner
// Tweak how sounds are played.
//
// Revision 1.1  2022/10/07 02:27:54  michaelmeissner
// Initial version.
//
